/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 09833
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1990
 |
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata provided
 | below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC COPY to copy the SAS transport
 | file to a SAS data set on their system. This program can then be used in
 | conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE cigtry    185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED CIGARETTES' 194='(194) DONT KNOW' 195='(195) BAD DATA'
                  196='(196) MULTIPLE RESPONSE' 198='(198) BLANK (NO ANSWER)' ;
  VALUE cig5pk    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigage    181='(181) NEVER USED CIGARETTES Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED CIGARETTES' 193='(193) NEVER SMOKED DAILY'
                  194='(194) DONT KNOW' 198='(198) BLANK (NO ANSWER)' ;
  VALUE cigyrs    181='(181) NEVER USED CIGARETTES Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED CIGARETTES' 194='(194) DONT KNOW'
                  198='(198) BLANK (NO ANSWER)'
                  199='(199) LEGITIMATE SKIP (CIGAGE = 193)' ;
  VALUE packs     1='(1) One to five cigarettes a day'
                  2='(2) About 1/2 pack a day (6-15 cigarettes)'
                  3='(3) About a pack a day (16-25 cigarettes)'
                  4='(4) About 1 1/2 packs a day (26-35 cigarette'
                  5='(5) About 2 packs or more a day(over 35 cigarettes)'
                  91='(91) NEVER USED CIGARETTES' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP (CIGAGE = 193)' ;
  VALUE cigrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than 1 year'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED CIGARETTES' 98='(98) BLANK' ;
  VALUE avcig     1='(1) Less than one cigarette a day'
                  2='(2) One to five cigarettes a day'
                  3='(3) About 1/2 pack a day (6-15 cigarettes)'
                  4='(4) About a pack a day (16-25 cigarettes)'
                  5='(5) About 1 1/2 packs a day (26-35 cigarettes)'
                  6='(6) About 2 packs or more a day (over 35 cigarettes)'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE cigtime   9981='(9981) NEVER USED CIGARETTES Logically assigned'
                  9985='(9985) BAD DATA Logically assigned'
                  9989='(9989) LEGITIMATE SKIP Logically assigned'
                  9991='(9991) NEVER USED CIGARETTES' 9994='(9994) DONT KNOW'
                  9995='(9995) BAD DATA' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE snufrec   1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than 1 year'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  91='(91) NEVER USED SMOKELESS TOBACCO' 98='(98) BLANK' ;
  VALUE othtob    1='(1) Daily' 2='(2) Almost daily (3-6 days a week)'
                  3='(3) 1 or 2 days a week'
                  4='(4) Several times a month (25-51 days a year)'
                  5='(5) 1 or 2 times a month (12-24 days a year)'
                  6='(6) Every other month or so (6-11 days a year)'
                  7='(7) 3-5 days this past year' 8='(8) 1 or 2 days this past year'
                  81='(81) NEVER USED SMOKELESS TOBACCO Log. assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED SMOKELESS TOBACCO IN LIFETIME'
                  93='(93) DID NOT USE SMOKELESS TOBACCO IN THE PAST YEAR'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alctry    181='(181) NEVER USED ALCOHOL Logically assigned'
                  185='(185) BAD DATA Logically assigned' 191='(191) NEVER USED ALCOHOL'
                  192='(192) ILLEGIBLE' 194='(194) DONT KNOW' 195='(195) BAD DATA'
                  197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE alcrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than 1 year'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ALCOHOL' ;
  VALUE alcage    181='(181) NEVER USED ALCOHOL Logically assigned'
                  185='(185) BAD DATA Logically assigned' 191='(191) NEVER USED ALCOHOL'
                  192='(192) ILLEGIBLE'
                  193='(193) NEVER USED ALCOHOL MONTHLY OR MORE OFTEN'
                  194='(194) DONT KNOW' 195='(195) BAD DATA' 196='(196) MULTIPLE RESPONSE'
                  197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE alcdays   81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  91='(91) NEVER USED ALCOHOL' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nodr30a   81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dr5day    81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30a   81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30dy  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcpat    1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25-51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drunkyr   1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25-51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  9='(9) Never got very high or drunk in past 12 months'
                  81='(81) NEVER USE ALCOHOL Logically assigned'
                  83='(83) DID NOT USED ALCOHOL PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTHS'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcsed    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alctran   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcstm    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcanal   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcmj     1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcinh    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alccoc    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alchal    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcopt    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcnone   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL PAST 12 MOS. Log. assigned'
                  85='(85) MULTIPLE RESPONSE' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcpref   1='(1) Beer' 2='(2) Wine' 3='(3) Liquor' 4='(4) It varies'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  85='(85) MULTIPLE RESPONSE Logically assigned'
                  91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nosedat   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE butisol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE buticaps  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amytal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mebaral   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE placidyl  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE doriden   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE noludar   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nembutal  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE seconal   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tuinal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dalmane   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE restoril  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halcion   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amobarb   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phenobar  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methaq    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE chhyd     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pentob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE secob     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sednewa   110='(110) Tuinal' 116='(116) Methaqualone (including Sopor, Quaalude)'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  121='(121) USED SEDATIVE, DONT KNOW NAME' 122='(122) Sleep Aid'
                  125='(125) Qulande' 126='(126) Somenx' 137='(137) 7-14' 201='(201) Valium'
                  226='(226) Stelazenorgin' 305='(305) Biphetamine' 331='(331) Whites'
                  332='(332) Ephedrine' 339='(339) Amphetamines (speed)'
                  360='(360) Rainbow (speed)' 406='(406) Percodan'
                  409='(409) Tylenol with Codeine' 415='(415) Codeine'
                  420='(420) OTHER Analgesic,NOT SPECIFIED' 422='(422) Motrin'
                  423='(423) Percocet' 425='(425) Advil' 430='(430) Asprin' 435='(435) Tylenol'
                  603='(603) Mescaline' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 991='(991) NEVER USED SEDATIVES'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewb   116='(116) Methaqualone (including Sopor, Quaalude)'
                  202='(202) Librium' 435='(435) Tylenol' 436='(436) Buffrin'
                  438='(438) Napersin,Naproseyn' 991='(991) NEVER USED SEDATIVES'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewc   201='(201) Valium' 991='(991) NEVER USED SEDATIVES'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE sednosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Sedative use LOGICALLY IMPUTED'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE seddknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedage    181='(181) NEVER USED SEDATIVES Logically assigned'
                  191='(191) NEVER USED SEDATIVES' 192='(192) ILLEGIBLE' 195='(195) BAD DATA'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE sedtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED SEDATIVES'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than 1 year'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  83='(83) DID NOT USE SEDATIVE PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE ANY SEDATIVE IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as3read   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE notranq   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE valium    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE librium   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE limbtrol  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE menrium   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE serax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranxene  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ativan    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE centrax   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE xanax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE paxipam   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE buspar    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE miltown   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE equanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE deprol    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE vistar    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE atarax    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE durrax    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE diazepam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skly      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE meprob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnewa    111='(111) Dalmane'
                  116='(116) Methaqualone (including Sopor, Quaalude)' 137='(137) 7-14'
                  201='(201) Valium' 221='(221) OTHER Tranquilizer, DONT KNOW NAME'
                  223='(223) Robaxin' 226='(226) Stelazenorgin' 228='(228) Amitriptyline'
                  231='(231) M.S' 425='(425) Advil' 434='(434) Vicodin' 435='(435) Tylenol'
                  801='(801) OTHER Drugs, NOT SPECIFIED'
                  991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewb    230='(230) Compazine' 991='(991) NEVER USED TRANQUILIZERS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewc    227='(227) Thorazine' 991='(991) NEVER USED TRANQUILIZERS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE trnosp    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Tranquilizer use LOGICALLY IMPUTED'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trdknam   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranage   181='(181) NEVER USED TRANQUILIZERS Logically assigned'
                  191='(191) NEVER USED TRANQUILIZERS' 195='(195) BAD DATA'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE trantot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED TRANQUILIZERS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranrec   1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than 1 year'
                  4='(4) 1 or more years ago but less than 3 year'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED TRANQUILIZERS Logically assigned'
                  83='(83) DID NOT USE TRANQUILIZER PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE ANY TRANQUILIZER IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as4read   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE nostims   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dexed     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dexamyl   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE eskat     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE benz      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE biphet    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE desoxyn   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tenuate   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tepanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE didrex    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE plegine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE preludin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ionamin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fastin    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pondimin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE voranil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sanorex   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mazanor   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ritalin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cylert    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE detamp    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methi     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methamp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Methamphetamine use LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE obla      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimnewa  124='(124) Yellow jackets' 321='(321) Methedrine'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant,NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 326='(326) White cross'
                  327='(327) Black Beauty, Black beauties' 328='(328) Pink hearts'
                  331='(331) Whites' 332='(332) Ephedrine' 333='(333) 357 Magnum, Magnum 44'
                  334='(334) Cross tops, Crossroads' 335='(335) Dexatrim'
                  339='(339) Amphetamines (speed)' 345='(345) Black Molly' 354='(354) Vivarin'
                  356='(356) Dexies' 357='(357) Heart shaped black pills' 358='(358) 20/20'
                  359='(359) Criss Cross' 601='(601) LSD' 614='(614) MDA'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 805='(805) Cocaine, Crack'
                  814='(814) Caffeine' 991='(991) NEVER USED STIMULANTS' 994='(994) DONT KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewb  322='(322) Methamphetamine (Speed or Crank)'
                  325='(325) USED STIMULANT DONT KNOW NAME' 326='(326) White cross'
                  327='(327) Black Beauty, Black beauties' 328='(328) Pink hearts'
                  329='(329) Robins eggs' 332='(332) Ephedrine'
                  604='(604) Psilocybin (mushrooms)' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 814='(814) Caffeine' 991='(991) NEVER USED STIMULANTS'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewc  124='(124) Yellow jackets' 991='(991) NEVER USED STIMULANTS'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewd  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  991='(991) NEVER USED STIMULANTS' 994='(994) DONT KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnosp  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Stimulant use LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmdknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimage   181='(181) NEVER USED STIMULANTS Logically assigned'
                  191='(191) NEVER USED STIMULANTS' 195='(195) BAD DATA'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE stimtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED STIMULANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than 1 year'
                  4='(4) 1 or more years ago but less than 3 years'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) DID NOT USE STIMULANT PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stneedle  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than 1 year'
                  4='(4) 1 or more years ago but less than 3 years'
                  5='(5) 3 or more years ago but less than 10 years'
                  6='(6) 10 or more years ago' 91='(91) NEVER USED STIMULANTS'
                  93='(93) NEVER USED AMPHETAMINES WITH A NEEDLE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as5read   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE analnone  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE darvon    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dolene    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sk65a     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wygesic   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE levodro   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE percodan  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE demerol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dilaud    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tylcod    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phencod   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talwin    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talwinnx  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talacen   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE propoxy   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE codeine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anilerid  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morphine  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methdon   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stadol    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analnewa  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  124='(124) Yellow jackets' 406='(406) Percodan' 415='(415) Codeine'
                  418='(418) Methadone' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  421='(421) USED ANALGESIC, DONT KNOW NAME' 422='(422) Motrin'
                  423='(423) Percocet' 426='(426) Fiornal' 427='(427) Darvocet'
                  430='(430) Asprin, Ecotrine' 431='(431) Tyloxe' 435='(435) Tylenol'
                  437='(437) Parafan Forte' 991='(991) NEVER USED ANALGESICS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewb  702='(702) Heroin' 991='(991) NEVER USED ANALGESICS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewc  420='(420) OTHER Analgesic, DONT KNOW NAME'
                  991='(991) NEVER USED ANALGESICS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE anlnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Analgesic use LOGICALLY IMPUTED'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anldknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analage   181='(181) NEVER USED ANALGESICS Logically assigned'
                  191='(191) NEVER USED ANALGESICS' 194='(194) DONT KNOW' 195='(195) BAD DATA'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE analtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED ANALGESICS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analrec   1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than 1 year'
                  4='(4) 1 or more years ago but less than 3 years'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anlyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED ANALGESICS Logically assigned'
                  83='(83) DID NOT USE ANALGESIC PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjopp     181='(181) NEVER HAD CHANCE TO TRY MARIJUANA'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER HAD CHANCE TO TRY MARIJUANA' 192='(192) ILLEGIBLE'
                  194='(194) DONT KNOW' 197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE mjage     181='(181) NEVER USED MARIJUANA Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED MARIJUANA' 192='(192) ILLEGIBLE' 194='(194) DONT KNOW'
                  195='(195) BAD DATA' 198='(198) BLANK (NO ANSWER)' ;
  VALUE mjtot     1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjrec     1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month'
                  3='(3) 1 or more months ago but less than 6 months'
                  4='(4) 6 or more months ago but less than 1 year'
                  5='(5) 1 or more years ago but less than 3 years'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA' ;
  VALUE mjday30a  81='(81) NEVER USED MARIJUANA Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjav30a   81='(81) NEVER USED MARIJUANA Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjamt30a  1='(1) Less than 10 joints in the past 30 days'
                  2='(2) 10 to 20 joints in the past 30 days'
                  3='(3) About 1 ounce in the past 30 days'
                  4='(4) About 2 ounces in the past 30 days'
                  5='(5) 3 to 4 ounces in the past 30 days'
                  6='(6) 5 to 6 ounces in the past 30 days'
                  7='(7) Unspecified but > 6 ounces in the past 30 days'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' ;
  VALUE mjyrfreq  1='(1) Several times a day' 2='(2) Daily'
                  3='(3) Almost daily (3 to 6 days a week)'
                  4='(4) 1 or 2 days a week'
                  5='(5) Several times a month (about 25 to 51 days)'
                  6='(6) 1 to 2 times a month (12 to 24 days a year)'
                  7='(7) Every other month or so (6 to 11 days a year)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjjoint   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjpipe    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjbake    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjchew    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjnewa    6='(6) Can with holes' 7='(7) One hitter' 8='(8) Boiled with tea'
                  9='(9) Smoky small room (burn in small room like bathroom)'
                  10='(10) With banana peels' 11='(11) Shot gun' 12='(12) Chewing/eating'
                  13='(13) Through an apple made like a pipe'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjnosp    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as7read   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE gas       1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sppaint   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE glue      1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE solvent   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amylnit   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ether     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nitoxid   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cleflu    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnewa   356='(356) Dexies' 502='(502) Spray paints'
                  504='(504) Shoeshine liquid, Glue, Toluene'
                  506='(506) Amyl nitrite (poppers, locker room)'
                  509='(509) Correction fluids, Degreasers, Cleaning'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens' 512='(512) Rush, Incense'
                  514='(514) Carbona' 516='(516) Freon' 518='(518) Nail Polish' 519='(519) Helium'
                  521='(521) Propane' 522='(522) TV Tuner' 523='(523) Matches' 605='(605) PCP'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 813='(813) Cigarettes and Tobacco'
                  814='(814) Caffeine' 991='(991) NEVER USED INHALANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnewb   517='(517) Tolyol' 991='(991) NEVER USED INHALANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE inhnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Inhalant use LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhage    181='(181) NEVER USED INHALANTS Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED INHALANTS' 194='(194) DONT KNOW'
                  195='(195) BAD DATA Logically assigned' 198='(198) BLANK (NO ANSWER)' ;
  VALUE inhtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhrec    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month'
                  3='(3) 1 or more months ago but less than 6 months'
                  4='(4) 6 or more months ago but less than 1 year'
                  5='(5) 1 or more years ago but less than 3 years'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN THE PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gas30a    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sppan30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 12 MOS.'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWWER)' ;
  VALUE glue30a   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USED INHALANT PAST 30 DAYS'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE solvn30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 12 MOS.'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE amlnt30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWWER)' ;
  VALUE ether30a  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USED INHALANT PAST 30 DAYS'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nox30a    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 12 MOS.'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE clfl30a   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE innew30a  504='(504) Shoeshine liquid, Glue, Toluene'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens' 518='(518) Nail polish, Acetone'
                  522='(522) TV Tuner' 523='(523) Matches'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 814='(814) Caffeine' 991='(991) NEVER USED INHALANTS'
                  993='(993) NOT APPLICABLE' 998='(998) BLANK (NO ANSWER)' ;
  VALUE innew30b  504='(504) Shoeshine liquid, Glue, Toluene'
                  991='(991) NEVER USED INHALANTS' 993='(993) NOT APPLICABLE'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE in30nosp  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANT PAST 30 DAYS'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inh30no   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdy30a  81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inheff    1='(1) Enough to feel it a little' 2='(2) Enough to feel it a lot'
                  3='(3) Enough to get high'
                  4='(4) Enough so that you staggered or dropped'
                  5='(5) Enough to feel you were going to pass out'
                  6='(6) Something else - unspecified'
                  7='(7) Didnt feel it, didnt use much'
                  8='(8) Sniffed out of curiosity once'
                  11='(11) Enough for a head rush'
                  12='(12) Didnt feel it,just like the smell'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhpo     1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc1f  1='(1) QUESTION 1 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc2f  2='(2) QUESTION 2 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc3f  3='(3) QUESTION 3 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc4f  4='(4) QUESTION 4 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc5f  5='(5) QUESTION 5 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc6f  6='(6) QUESTION 6 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc7f  7='(7) QUESTION 7 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc8f  8='(8) QUESTION 8 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc9f  9='(9) QUESTION 9 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc0f  10='(10) ALL QUESTIONS WERE CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhansy   1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE cocopp    181='(181) NEVER HAD A CHANCE TO TRY COCAINE'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER HAD A CHANCE TO TRY COCAINE' 194='(194) DONT KNOW'
                  197='(197) REFUSED' 198='(198) BLANK (NO ANSWER)' ;
  VALUE cocage    181='(181) NEVER USED COCAINE Logically assigned'
                  185='(185) BAD DATA Logically assigned' 191='(191) NEVER USED COCAINE'
                  195='(195) BAD DATA' ;
  VALUE coctot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocrec    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE' ;
  VALUE cocus30a  81='(81) NEVER USED COCAINE Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE' ;
  VALUE cocyrfrq  1='(1) Daily' 2='(2) Almost daily (3 to 6 days a week)'
                  3='(3) 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocsniff  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocswal   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cociv     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Cocaine use LOGICALLY IMPUTED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE freebase  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Cocaine use LOGICALLY IMPUTED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocnewa   6='(6) Lasing (sic) joints and bongs' 7='(7) On my gums'
                  8='(8) Freeze, put on tongue, etc'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocnewb   7='(7) On my gums' 81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocnosp   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE PAST 12 MONTHS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE condlrec  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) NEVER USED COCAINE WITH A NEEDLE' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE crakrec   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED' 91='(91) NEVER USED CRACK'
                  97='(97) REFUSED' ;
  VALUE crkam30a  981='(981) NEVER USED Logically assigned'
                  983='(983) DID NOT USE CRACK IN PAST 30 DAYS'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED CRACK'
                  993='(993) DID NOT USE CRACK IN PAST 30 DAYS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE crakbuck  9981='(9981) NEVER USED COCAINE Logically assigned'
                  9983='(9983) DID NOT USE CRACK PAST 30 DAYS'
                  9985='(9985) BAD DATA Logically assigned' 9991='(9991) NEVER USED CRACK'
                  9993='(9993) DID NOT USE CRACK IN PAST 30 DAYS' 9997='(9997) REFUSED' ;
  VALUE cocam30a  1='(1) Less than 1/4 gram (about 4 big lines)'
                  2='(2) About 1/4 gram in the past 30 days'
                  3='(3) About 1/2 gram in the past 30 days'
                  4='(4) About 1 gram in the past 30 days'
                  5='(5) About 2 grams in the past 30 days'
                  6='(6) About 3 grams in the past 30 days'
                  7='(7) Unspecified but >3 grams in past 30 days'
                  8='(8) 4 grams in the past 30 days'
                  10='(10) Unspecified but >3 grams in past 30 days'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocbuck   9981='(9981) NEVER USED COCAINE Logically assigned'
                  9983='(9983) DID NOT USE COCAINE PAST 30 DAYS'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED COCAINE'
                  9993='(9993) DID NOT USE COCAINE IN PAST 30 DAYS' 9994='(9994) DONT KNOW'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE as9read   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE lsd       1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE peyote    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mesc      1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE psilcy    1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcp       1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) PCP use LOGICALLY IMPUTED' 91='(91) NEVER USED HALLUCINOGENS'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ecstasy   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnewa   210='(210) Paxipam' 336='(336) Diet pills' 604='(604) Psilocybin Mushrooms'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 608='(608) ORGAN-Z5'
                  614='(614) MDA' 616='(616) DMT' 617='(617) Morning glory seeds'
                  802='(802) THC, Cannabinol' 991='(991) NEVER USED HALLUCINOGENS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewb   607='(607) OTHER HALLUCINOGEN, NOT SPECIFIED'
                  801='(801) OTHER Drugs, NOT SPECIFIED'
                  991='(991) NEVER USED HALLUCINOGENS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE halnosp   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Hallucinogen use LOGICALLY IMPUTED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE haldknam  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallopp   181='(181) NEVER HAD A CHANCE TO TRY HALLUCINOGENS'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER HAD A CHANCE TO TRY HALLUCINOGENS'
                  194='(194) DONT KNOW' 198='(198) BLANK (NO ANSWER)' ;
  VALUE hallage   181='(181) NEVER USED HALLUCINOGENS Logically assigned'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER USED HALLUCINOGENS' 194='(194) DONT KNOW'
                  195='(195) BAD DATA' 198='(198) BLANK (NO ANSWER)' ;
  VALUE halltot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hal30use  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halyrfrq  1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED HALLUCINOGENS Logically assigned'
                  83='(83) DID NOT USE HALLUCINOGEN PAST 12 MOS.'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGEN IN THE PAST 12 MONTHS'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcprec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED' 91='(91) NEVER USED PCP' ;
  VALUE as10read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE heropp    181='(181) NEVER HAD A CHANCE TO TRY HEROIN'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER HAD A CHANCE TO TRY HEROIN' 194='(194) DONT KNOW'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE herage    181='(181) NEVER HAD A CHANCE TO TRY HEROIN'
                  185='(185) BAD DATA Logically assigned'
                  191='(191) NEVER HAD A CHANCE TO TRY HEROIN'
                  198='(198) BLANK (NO ANSWER)' ;
  VALUE hertot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOCIGALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HEROIN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE her30use  81='(81) NEVER USED HEROIN Logically assigned'
                  91='(91) NEVER USED HEROIN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE herneedl  1='(1) Yes, have used heroin with a needle'
                  2='(2) No, have used heroin, but not with a needle'
                  3='(3) Yes, have used heroin with needle Logically assign.'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  91='(91) NEVER USED HEROIN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hrndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HEROIN' 93='(93) NEVER USED HEROIN WITH A NEEDLE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as11read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE cdcig     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log.'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdalc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log.'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdsed     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log.'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdtran    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log.'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdstm     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdanal    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdmj      1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdinh     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdcoc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS.'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdhall    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdher     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdothop   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not try to cut down on any drug in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdnone    1='(1) Response circled' 2='(2) Response not circled'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effcig    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effalc    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effsed    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MONTHS LOG. ASSIGNED'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE efftran   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effstm    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effanal   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effmj     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effinh    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effcoc    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effhall   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effher    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effothop  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE effnone   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not need more of any drug used for same effect'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udaycig   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udayalc   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udaysed   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udaytran  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udaystm   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udayanal  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udaymj    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udayinh   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udaycoc   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udayhall  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udayher   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udayoth   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE udaynone  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not use any drug daily in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE depcig    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE depalc    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE depsed    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE deptran   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE depstm    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE depanal   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE depmj     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE depinh    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE depcoc    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dephall   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE depher    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE depothop  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE depnone   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not feel like had to have any drug used past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wscig     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wsalc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wssed     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wstran    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wsstm     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wsanal    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wsmj      1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wsinh     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wscoc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wshall    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wsher     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wsothop   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE wsnone    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Did not have withdrawal symptoms in past year'
                  83='(83) DID NOT USE ANY DRUGS PAST 12 MOS. Log. assigned'
                  85='(85) BAD DATA Log. assigned'
                  93='(93) DID NOT USE ANY DRUGS IN PAST 12 MONTHS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE icelife   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  81='(81) NEVER USED ICE Logically assigned'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE icerec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  6='(6) 10 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ICE Logically assigned' 91='(91) NEVER USED ICE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as12read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE gnndllif  1='(1) Response circled' 3='(3) Response circled LOGICALLY IMPUTED'
                  81='(81) NEVER USED NEEDLE TO TAKE DRUG Log. assigned'
                  91='(91) NEVER USED A NEEDLE TO TAKE A DRUG' ;
  VALUE gnndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED ANY DRUG FOR NONMDCL RSN'
                  91='(91) NEVER USED ANY DRUG FOR NONMEDICAL RSNS'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG' ;
  VALUE gnndlsed  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. assigned'
                  83='(83) NEVER USED NEEDLE TO TAKE DRUG Log. assigned'
                  85='(85) BAD DATA Log. assgnd'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndltra  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY LISTED DRUGS Log. assgnd'
                  83='(83) NEVER USED ANY DRUGS LIST ABOVE Log. assigned'
                  85='(85) NEVER USED NEEDLE TO TAKE DRUG Log. asigned'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlstm  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled Log. imputed'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. assigned'
                  83='(83) NEVER USED NEEDLE TO TAKE DRUG Log. assg'
                  85='(85) BAD DATA Log. assgnd'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlanl  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. assigned'
                  83='(83) NEVER USED NEEDLE TO TAKE DRUG Log. assg'
                  85='(85) BAD DATA Log. assgnd'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlmj   1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. assigned'
                  83='(83) NEVER USED NEEDLE TO TAKE DRUG Log. assigned'
                  85='(85) BAD DATA Log. assgnd'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlinh  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. assigned'
                  83='(83) NEVER USED NEEDLE TO TAKE DRUG Log. assg'
                  85='(85) BAD DATA Log. assgnd'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlcoc  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. assigned'
                  83='(83) NEVER USED NEEDLE TO TAKE DRUG Log. assg'
                  85='(85) BAD DATA Log. assgnd'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlhal  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. assigned'
                  83='(83) NEVER USED NEEDLE TO TAKE DRUG Log. assg'
                  85='(85) BAD DATA Log. assgnd'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlher  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. assigned'
                  83='(83) NEVER USED NEEDLE TO TAKE DRUG Log. assg'
                  85='(85) BAD DATA Log. assgnd'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlopt  1='(1) Response circled' 2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. assigned'
                  83='(83) NEVER USED NEEDLE TO TAKE DRUG Log. assg'
                  85='(85) BAD DATA Log. assgnd'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlnon  2='(2) Response not circled'
                  81='(81) NEVER USED ANY DRUGS LIST ABOVE Log. assigned'
                  83='(83) NEVER USED NEEDLE TO TAKE DRUG Log. assg'
                  85='(85) BAD DATA Log. assgnd'
                  91='(91) NEVER USED ANY OF THE DRUGS LISTED ABOVE'
                  93='(93) NEVER USED A NEEDLE TO TAKE ANY DRUG'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gnndlshr  1='(1) Yes' 2='(2) No' 81='(81) NEVER SHARED A NEEDLE Log. assgnd'
                  91='(91) NEVER SHARED A NEEDLE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE as13read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE noboozyr  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  85='(85) BAD DATA Log. assgnd' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcaggr   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcargum  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcabsnt  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alchigh   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcjob    1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcmatcd  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcrelcd  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcfrdcd  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alctoss   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcholic  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcdrunk  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcintox  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcrem    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcquick  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcmorn   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcshook  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcalone  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE alcbrkpm  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOZYR=1 or 3)' ;
  VALUE as13none  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  85='(85) BAD DATA Log. assgnd' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drdeprss  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE=1 or 3)' ;
  VALUE depdrg1a  112='(112) Restoril'
                  116='(116) Methaqualone (including Sopor, Quaalude)'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  121='(121) USED SEDATIVE, DONT KNOW NAME' 123='(123) Unisom'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine' 339='(339) Amphetamines (speed)' 348='(348) Crystal'
                  401='(401) Darvon' 501='(501) Gasoline or lighter fluids'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 808='(808) All of the ones Ive tried'
                  812='(812) Cigars' 813='(813) Cigarettes, Tobacco'
                  900='(900) NON-DRUG REASON' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDEPRSS=2,99)' ;
  VALUE depdrg2a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers' 201='(201) Valium'
                  209='(209) Xanax' 332='(332) Ephedrine' 336='(336) Diet pills'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDEPRSS=2,99)' ;
  VALUE depdrg3a  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (Speed or Crank)'
                  409='(409) Tylenol with Codeine' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDEPRSS=2,99)' ;
  VALUE depdrg4a  807='(807) Alcohol' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDEPRSS=2,99)' ;
  VALUE drargum   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  85='(85) BAD DATA Log. assgnd' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE argdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers' 123='(123) Unisom'
                  209='(209) Xanax' 322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine' 336='(336) Diet pills' 348='(348) Crystal'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens'
                  601='(601) LSD (acid, white lightning)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 808='(808) All of the ones Ive tried' 812='(812) Cigars'
                  813='(813) Cigarettes, Tobacco'
                  816='(816) Smokeless tobacco - snuff/chewing'
                  900='(900) NON-DRUG REASON' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRARGUM=2,99)' ;
  VALUE argdrg2a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers' 201='(201) Valium'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 336='(336) Diet pills'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 813='(813) Cigarettes, Tobacco'
                  900='(900) NON-DRUG REASON' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRARGUM=2,99)' ;
  VALUE argdrg3a  201='(201) Valium' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  409='(409) Tylenol with Codeine' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRARGUM=2,99)' ;
  VALUE dralone   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE=1 or 3)' ;
  VALUE alndrg1a  116='(116) Methaqualone (including Sopor, Quaalude)'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  121='(121) USED SEDATIVE, DONT KNOW NAME' 123='(123) Unisom'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 332='(332) Ephedine'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 808='(808) All of the ones Ive tried'
                  813='(813) Cigarettes, Tobacco1' 900='(900) NON-DRUG REASON'
                  994='(994) DONT KNOW' 995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRALONE=2,99)' ;
  VALUE alndrg2a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  336='(336) Diet pills' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRALONE=2,99)' ;
  VALUE alndrg3a  221='(221) OTHER Tranquilizer, NOT SPECIFIED1'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRALONE=2,99)' ;
  VALUE dranx     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE=1 or 3)' ;
  VALUE anxdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  122='(122) Sleep Aid' 201='(201) Valium' 209='(209) Xanax'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME'
                  329='(329) Speckled Eggs, Robins Eggs' 332='(332) Ephedrine'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed)' 348='(348) Crystal'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens' 513='(513) Tulio Osica'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 812='(812) Cigars'
                  813='(813) Cigarettes, Tobacco' 814='(814) Caffeine'
                  900='(900) NON-DRUG REASON' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP (DRANX=2,99)' ;
  VALUE anxdrg2a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 336='(336) Diet pills'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 900='(900) NON-DRUG REASON'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP (DRANX=2,99)' ;
  VALUE anxdrg3a  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)' 803='(803) Marijuana'
                  807='(807) Alcohol' 900='(900) NON-DRUG REASON' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRANX=2,99)' ;
  VALUE drhealth  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  85='(85) BAD DATA Log. assgnd' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME'
                  339='(339) Amphetamine (speed)' 348='(348) Crystal' 426='(426) Fiorinal'
                  430='(430) Aspirin, Ecotrine' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, Tobacco' 900='(900) NON-DRUG REASON'
                  994='(994) DONT KNOW' 995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRHEALTH=2,99)' ;
  VALUE hltdrg2a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  900='(900) NON-DRUG REASON' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRHEALTH=2,99)' ;
  VALUE hltdrg3a  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRHEALTH=2,99)' ;
  VALUE drnthink  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE=1 or 3)' ;
  VALUE ntkdrg1a  116='(116) Methaqualone (including Sopor, Quaalude)'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  122='(122) Sleep Aid' 201='(201) Valium' 209='(209) Xanax'
                  222='(222) USED TRANQUILIZER, DONT KNOW NAME'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 348='(348) Crystal'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 812='(812) Cigars'
                  813='(813) Cigarettes, Tobacco' 900='(900) NON-DRUG REASON'
                  995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNTHINK=2,99)' ;
  VALUE ntkdrg2a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  409='(409) Tylenol with Codeine' 417='(417) Morphine'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 900='(900) NON-DRUG REASON'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNTHINK=2,99)' ;
  VALUE ntkdrg3a  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 603='(603) Mescaline'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNTHINK=2,99)' ;
  VALUE ntkdrg4a  803='(803) Marijuana' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNTHINK=2,99)' ;
  VALUE drupset   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE=1 or 3)' ;
  VALUE upsdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  122='(122) Sleep Aid' 201='(201) Valium'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 332='(332) Ephedrine'
                  336='(336) Diet pills' 348='(348) Crystal' 409='(409) Tylenol with Codeine'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens'
                  601='(601) LSD (acid, white lightning)'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 813='(813) Cigarettes, Tobacco'
                  814='(814) Caffeine' 815='(815) Coffee' 817='(817) Hardstuff'
                  900='(900) NON-DRUG REASON' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRUPSET=2,99)' ;
  VALUE upsdrg2a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  336='(336) Diet pills' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 900='(900) NON-DRUG REA'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRUPSET=2,99)' ;
  VALUE upsdrg3a  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRUPSET=2,99)' ;
  VALUE drlswork  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE=1 or 3)' ;
  VALUE lswdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers' 201='(201) Valium'
                  222='(222) USED TRANQUILIZER, DONT KNOW NAME'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 348='(348) Crystal'
                  409='(409) Tylenol with Codeine'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 813='(813) Cigarettes, Tobacco'
                  900='(900) NON-DRUG REASON' 995='(995) BAD DATA'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRLSWORK=2,99)' ;
  VALUE lswdrg2a  201='(201) Valium' 324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  601='(601) LSD (acid, white lightning)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 900='(900) NON-DRUG REASON'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRLSWORK=2,99)' ;
  VALUE lswdrg3a  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRLSWORK=2,99)' ;
  VALUE drsuspic  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE=1 or 3)' ;
  VALUE sspdrg1a  116='(116) Methaqualone (including Sopor, Quaalude)'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  122='(122) Sleep Aid' 322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 348='(348) Crystal'
                  353='(353) No-Doz' 511='(511) Markers, Felt-tip pens'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 813='(813) Cigarettes, Tobacco1'
                  900='(900) NON-DRUG REASON' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRSUSPIC=2,99)' ;
  VALUE sspdrg2a  702='(702) Heroin' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  900='(900) NON-DRUG REASON' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRSUSPIC=2,99)' ;
  VALUE sspdrg3a  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRSUSPIC=2,99)' ;
  VALUE drcope    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE=1 or 3)' ;
  VALUE cpedrg1a  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  122='(122) Sleep Aid' 322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 348='(348) Crystal'
                  426='(426) Fiorinal' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  702='(702) Heroin' 803='(803) Marijuana' 804='(804) Hashish'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 813='(813) Cigarettes, Tobacco1'
                  900='(900) NON-DRUG REASON' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP (DRCOPE=2,99)' ;
  VALUE cpedrg2a  201='(201) Valium' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  702='(702) Heroin' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  900='(900) NON-DRUG REASON' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRCOPE=2,99)' ;
  VALUE cpedrg3a  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP (DRCOPE=2,99)' ;
  VALUE dremgmed  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE=1 or 3)' ;
  VALUE emdrg1a   603='(603) Mescaline' 702='(702) Heroin' 803='(803) Marijuana' 804='(804) Hashish'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  900='(900) NON-DRUG REASON' 995='(995) BAD DATA' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP (DREMGMED=2,99)' ;
  VALUE emdrg2a   803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  900='(900) NON-DRUG REASON' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP (DREMGMED=2,99)' ;
  VALUE emdrg3a   806='(806) Crack' 807='(807) Alcohol' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP (DREMGMED=2,99)' ;
  VALUE emdrg4a   601='(601) LSD (acid, white lightning)' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP (DREMGMED=2,99)' ;
  VALUE rskpkcig  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rsktrymj  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrypcp  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkpcpreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktryher  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 92='(92) ILLEGIBLE' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkherreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrycoc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcococc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcocreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcrkocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkansocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWWER)' ;
  VALUE rkansreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rk2drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rk5drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rskbinge  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE highbp    1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE bpmed     1='(1) Yes' 2='(2) No' 92='(92) ILLEGIBLE' 94='(94) DONT KNOW' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE walkpain  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK' ;
  VALUE timepain  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE upshor    1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE asthma    1='(1) Yes' 2='(2) No' 92='(92) ILLEGIBLE' 94='(94) DONT KNOW' 98='(98) BLANK' ;
  VALUE trpsych   1='(1) Yes' 2='(2) No' 92='(92) ILLEGIBLE' 94='(94) DONT KNOW' 98='(98) BLANK' ;
  VALUE heart     1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE flu       1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK' ;
  VALUE allerg    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK' ;
  VALUE hospyr    1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE soreyr    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE runnyyr   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE coughyr   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE phlegmyr  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE healthyr  1='(1) Excellent' 2='(2) Very good' 3='(3) Good' 4='(4) Fair' 5='(5) Poor'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE helthins  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE marital   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or separated'
                  4='(4) Has never married' 85='(85) BAD DATA Log. assgnd'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP (IRAGE<15)' ;
  VALUE nomarr    85='(85) BAD DATA Log. assgnd' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (IRAGE<15 or MARITAL=4)' ;
  VALUE workstat  1='(1) Working full-time, 35 hours or more a week'
                  2='(2) Working part-time, less than 35 hours a week'
                  3='(3) Have job but out: illness/leave/furlough'
                  4='(4) Unemployed or laid off and looking for week'
                  5='(5) Unemployed and not looking for work'
                  6='(6) Full-time homemaker only' 7='(7) In school only' 8='(8) Retired'
                  9='(9) Disabled, not able to work'
                  10='(10) Something else (NOT SPECIFIED)'
                  11='(11) Unable to work - taking care of ill relatives'
                  12='(12) About to start work'
                  13='(13) Contracts for work (eg. Musician)' 14='(14) Welfare (AFDC)'
                  15='(15) Out of work - Termination - Injury'
                  16='(16) Just got out of school' 18='(18) Drop out of school'
                  19='(19) Full time but less than 35 hours per week'
                  21='(21) Volunteer' 22='(22) Babysitting' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE paymo     85='(85) BAD DATA Log. assgnd' 91='(91) NEVER WORKED FOR PAY'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (WORKSTAT<4)' ;
  VALUE payyr     91='(91) NEVER WORKED FOR PAY' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (WORKSTAT<4)' ;
  VALUE roccup2f  990='(990) OCCUPATION NOT REPORTED' 995='(995) BAD DATA' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE businesf  990='(990) INDUSTRY NOT REPORTED' 995='(995) BAD DATA' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE sector    1='(1) Manufacturing,' 2='(2) Wholesale trade,'
                  3='(3) Retail trade, or' 4='(4) Something else? (SPECIFY)'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE no5job    94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE workdays  94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE workblah  85='(85) BAD DATA Log. assgnd' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cwe       1='(1) Respondent' 2='(2) Someone else (NOT SPECIFIED)'
                  3='(3) Income Contributed Equally' 4='(4) No one'
                  11='(11) Head of Household,Employer'
                  12='(12) Spouse,Ex-husband supports'
                  13='(13) Live-in partner,fiancee' 14='(14) Mother' 15='(15) Father'
                  16='(16) Daughter' 17='(17) Son' 18='(18) Sister' 19='(19) Brother'
                  20='(20) Grandmother' 21='(21) Grandfather'
                  22='(22) Other female blood relative'
                  23='(23) Other male blood relative' 24='(24) Mother-in-law'
                  25='(25) Father-in-law' 26='(26) Other female in-laws'
                  27='(27) Other male in-laws' 28='(28) Close female friend'
                  29='(29) Close male friend'
                  30='(30) Other female acquaintance, roommate'
                  31='(31) Other male acquaintance, roommate' 32='(32) Step-mother'
                  33='(33) Step-father' 38='(38) Other step relative, male'
                  40='(40) Friend (sex unspecified),boarder' 41='(41) Parents'
                  42='(42) Grandparents' 44='(44) Foster mother, female guardian'
                  45='(45) Foster father, male guardian'
                  50='(50) Multiple people listed'
                  51='(51) Relative, sex not specified'
                  52='(52) Roomate, sex not specified' 92='(92) ILLEGIBLE'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEG. SKIP (RESP IS ONLY ADULT 18 OR OLDER)' ;
  VALUE fullpart  1='(1) Full-time' 2='(2) Part-time'
                  3='(3) Chief source of income does not work' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE cweocc2f  990='(990) OCCUPATION NOT REPORTED' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (CWE=1,3,99 or FULLPART=' ;
  VALUE cwebus2f  990='(990) INDUSTRY NOT REPORTED' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (CWE=1,3,99 or FULLPART=' ;
  VALUE cwesectr  1='(1) Manufacturing,' 2='(2) Wholesale trade,'
                  3='(3) Retail trade, or' 4='(4) Something else? (SPECIFY)'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK' 99='(99) LEGITIMTE SKIP' ;
  VALUE educ      0='(0) No schooling' 1='(1) First Grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh Grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) One year college'
                  14='(14) 2 years college' 15='(15) 3 years college'
                  16='(16) 4 years college' 17='(17) Graduate/professional school'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE gradhs    1='(1) YES' 2='(2) NO' 92='(92) ILLEGIBLE' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE diploma   1='(1) High school diploma' 2='(2) GED certificate'
                  3='(3) Neither of the above' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP(EDUC>12,GRADHS=2/IRAGE<1' ;
  VALUE enrolld   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY IMPUTED' 97='(97) REFUSED'
                  98='(98) BLANK' ;
  VALUE student   1='(1) A full-time student' 2='(2) A part-time student'
                  97='(97) REFUSED' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP (ENROLLD=2)' ;
  VALUE schdays   92='(92) ILLEGIBLE' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (ENROLLD=2)' ;
  VALUE skipped   97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (ENROLLD=2)' ;
  VALUE schplans  1='(1) Has plans to enroll in a school in future'
                  2='(2) Has completed all schooling' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP (IRAGE>22)' ;
  VALUE miles     99991='(99991) HAS NEVER DRIVEN A MOTOR VEHICLE' 99994='(99994) DONT KNOW'
                  99997='(99997) REFUSED' 99998='(99998) BLANK (NO ANSWER)'
                  99999='(99999) LEGITIMATE SKIP (IRAGE<15)' ;
  VALUE accid     1='(1) Yes' 2='(2) No' 3='(3) Did not drive in past 12 months'
                  85='(85) BAD DATA Log. assgnd' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP (IRAGE<15 or MILES=99991' ;
  VALUE nochild   94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (IRAGE<15)' ;
  VALUE totpeop   97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE mother    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE father    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE stepmom   0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE stepdad   0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE spouse    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE inlaw     93='(93) RELATION INDICATED, NO COUNT RECORDED' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ownchild  93='(93) RELATION INDICATED, NO COUNT RECORDED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE stepchld  93='(93) RELATION INDICATED, NO COUNT RECORDED' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE brosis    93='(93) RELATION INDICATED, NO COUNT RECORDED' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE othrel    93='(93) RELATION INDICATED, NO COUNT RECORDED' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE friends   93='(93) RELATION INDICATED, NO COUNT RECORDED' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE othernon  93='(93) RELATION INDICATED, NO COUNT RECORDED' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE service   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP (IRAGE<17)' ;
  VALUE milstat   1='(1) On extended active duty in the Armed Forces'
                  2='(2) In a Reserves component'
                  3='(3) Separated/retired from Reserves or active duty'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP (IRAGE<17 or SERVICE=2)' ;
  VALUE movdaway  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE dorm      94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE milbase   94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE hosp      94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MOVDAWAY=2)' ;
  VALUE telno     94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE moves     94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE income    1='(1) No personal earnings' 2='(2) Yearly under $5,000'
                  3='(3) Yearly $5,000 to $6,999' 4='(4) Yearly $7,000 to $8,999'
                  5='(5) Yearly $9,000 to $11,999' 6='(6) Yearly $12,000 to $14,999'
                  7='(7) Yearly $15,000 to $19,999' 8='(8) Yearly $20,000 to $24,999'
                  9='(9) Yearly $25,000 to $29,999'
                  10='(10) Yearly $30,000 to $39,999'
                  11='(11) Yearly $40,000 to $49,999'
                  12='(12) Yearly $50,000 to $74,999'
                  13='(13) Yearly more than $75,000' 85='(85) BAD DATA Log. assgnd'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP (IRAGE<15)' ;
  VALUE wksworkd  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wksfp     1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE totfamin  1='(1) No family income' 2='(2) Yearly Under $5,000'
                  3='(3) Yearly $5,000 to $6,999' 4='(4) Yearly $7,000 to $8,999'
                  5='(5) Yearly $9,000 to $11,999' 6='(6) Yearly $12,000 to $14,999'
                  7='(7) Yearly $15,000 to $19,999' 8='(8) Yearly $20,000 to $24,999'
                  9='(9) Yearly $25,000 to $29,999'
                  10='(10) Yearly $30,000 to $39,999'
                  11='(11) Yearly $40,000 to $49,999'
                  12='(12) Yearly $50,000 to $74,999' 13='(13) Yearly $75,000 or More'
                  85='(85) BAD DATA Log. assgnd' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK(NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wages     1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE selfempl  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE intdiv    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE socsec    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ssi       1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE disablty  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE othretir  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE welfare   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE othsourc  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE amtwages  999992='(999992) ILLEGIBLE' 999994='(999994) DONT KNOW' 999995='(999995) BAD DATA'
                  999997='(999997) REFUSED' 999998='(999998) BLANK (No Answer)'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE amtselfe  999994='(999994) DONT KNOW' 999995='(999995) BAD DATA' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (No Answer)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE amtintdv  999994='(999994) DONT KNOW' 999995='(999995) BAD DATA' 999997='(999997) REFUSED'
                  999998='(999998) BLANK' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE amtsosec  999994='(999994) DONT KNOW' 999995='(999995) BAD DATA' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (No Answer)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE amtssi    999994='(999994) DONT KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (No Answer)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE amtdisab  999994='(999994) DONT KNOW' 999997='(999997) REFUSED' 999998='(999998) BLANK'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE amtotret  999994='(999994) DONT KNOW' 999995='(999995) BAD DATA' 999997='(999997) REFUSED'
                  999998='(999998) BLANK' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE amtwlfar  999994='(999994) DONT KNOW' 999997='(999997) REFUSED'
                  999998='(999998) BLANK (No Answer)' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE amtotsrc  999994='(999994) DONT KNOW' 999997='(999997) REFUSED' 999998='(999998) BLANK'
                  999999='(999999) LEGITIMATE SKIP' ;
  VALUE bap       1='(1) AM' 2='(2) PM' ;
  VALUE eap       1='(1) AM' 2='(2) PM' 96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE langver   1='(1) English' 2='(2) Spanish' ;
  VALUE undint    1='(1) No difficulty-no language/reading problem'
                  2='(2) Just a little difficulty-almost no lang/reading problem'
                  3='(3) Fair amount of difficulty-some lang/reading problem'
                  4='(4) A lot of difficulty-considerable lang/reading problem'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE coopint   1='(1) Very cooperative' 2='(2) Fairly cooperative'
                  3='(3) Not very cooperative' 4='(4) Openly hostile'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE privacy   1='(1) Completely private-no one present/able to overhear'
                  3='(3) Minor distractions'
                  5='(5) Person(s) in room or listening 1/3 of the time'
                  7='(7) Serious interruptions more than half the time'
                  9='(9) Constant presence of other person(s)'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ppres     1='(1) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE spres     2='(2) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE parpres   3='(3) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE oarpres   4='(4) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE oapres    5='(5) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE cpres     6='(6) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE opresspa  2='(2) Spouse' 3='(3) Live-in partner,fiancee' 4='(4) Mother'
                  16='(16) Daughter' 17='(17) Son' 18='(18) Sister' 19='(19) Brother'
                  20='(20) Grandmother' 21='(21) Grandfather'
                  22='(22) Other female blood relative' 24='(24) Mother-in-law'
                  28='(28) Close female friend' 29='(29) Close male friend'
                  30='(30) Other female acquaintance, roommate'
                  31='(31) Other male acquaintance, roommate'
                  40='(40) Friend (sex unspecified)' 42='(42) Granparents'
                  43='(43) Guardian (sex unspecified)'
                  44='(44) Foster mother, female guardian'
                  46='(46) Governess, nanny or live-in babysitter'
                  48='(48) Housekeeper or maid' 50='(50) Multiple people listed'
                  51='(51) Relative, sex not specified'
                  52='(52) Roommate, sex not specified' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE opresspb  18='(18) Sister' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE opresnsp  7='(7) Response circled' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE popden    1='(1) 1,000,000 or more persons in the SMSA'
                  2='(2) 50,000 to 999,999 persons in the SMSA'
                  3='(3) Not in the SMSA' ;
  VALUE popden2f  1='(1) 1,000,000 or more persons in the SMSA'
                  2='(2) 250,000 to 999,999 persons in the SMSA'
                  3='(3) Fewer than 250,000 persons in the SMSA'
                  4='(4) Not in an SMSA and not in a rural area'
                  5='(5) Not in an SMSA and in a rural area' ;
  VALUE dc        1='(1) Segment in the Low SES portion of the DC MSA'
                  2='(2) Segment in the remainder of the DC MSA'
                  9='(9) Segment not in the DC MSA' ;
  VALUE cencty    1='(1) Segment is in the DC MSA and Wash, DC, the Central City'
                  2='(2) Segment is in the DC MSA but not in Wash, DC, Central City'
                  3='(3) Segment not within the DC MSA' ;
  VALUE urbare    1='(1) Segment in the DC MSA and in the DC Urbanized Area'
                  2='(2) Segment in the DC MSA but not in the DC Urbanized Area'
                  3='(3) Not in the DC MSA' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE division  1='(1) New England' 2='(2) Middle Atlantic' 3='(3) East North Central'
                  4='(4) West North Central' 5='(5) South Atlantic'
                  6='(6) East South Central' 7='(7) West South Central' 8='(8) Mountain'
                  9='(9) Pacific' ;
  VALUE hsphconc  1='(1) Equal to or greater than 50% Hispanic households'
                  2='(2) 10% or more but less than 50% Hispanic households'
                  3='(3) Less than 10% Hispanic households' ;
  VALUE hsppconc  1='(1) Equal to or greater than 50% Hispanic persons'
                  2='(2) 10% or more but less than 50% Hispanic persons'
                  3='(3) Less than 10% Hispanic persons' ;
  VALUE nhbhconc
                  1='(1) Equal to or greater than 50% NonHispanic black households'
                  2='(2) 10% or more but less than 50% NonHispanic black households'
                  3='(3) Less than 10% NonHispanic black households' ;
  VALUE nhbpconc  1='(1) Equal to or greater than 50% NonHispanic black persons'
                  2='(2) 10% or more but less than 50% Nonhispanic black persons'
                  3='(3) Less than 10% NonHispanic black persons' ;
  VALUE ownoconc
                  1='(1) Equal to or greater than 50% Owner Occupied Housing Units'
                  2='(2) 10% or more but less than 50% Owner Occupied Housing Units'
                  3='(3) Less than 10% Owner Occupied Housing Units' ;
  VALUE iiage     1='(1) Age taken from birthdate'
                  2='(2) Age taken from questionnaire'
                  3='(3) Age taken from screener' 4='(4) Age imputed' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE iisex     1='(1) Sex taken from questionnaire'
                  2='(2) Sex taken from screener' ;
  VALUE irrace    1='(1) American Indian or Alaskan Native'
                  2='(2) Asian or Pacific Islander' 3='(3) Black' 4='(4) White' ;
  VALUE iirace    1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Not Hispanic' ;
  VALUE iihoind   1='(1) Hispanic Origin taken from questionnaire'
                  2='(2) Hispanic Origin logically imputed'
                  3='(3) Statistically imputed data' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iihogrp   1='(1) Hispanic-Origin Group taken from questionnaire'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irmarit   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or Separated'
                  4='(4) Never Married' 99='(99) LEGITIMATE SKIP' ;
  VALUE iimarit   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE ireduc    0='(0) No schooling' 1='(1) First grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) One year of college'
                  14='(14) Two years of college' 15='(15) Three years of college'
                  16='(16) Four years of college'
                  17='(17) Graduate/professional school' ;
  VALUE iieduc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irhsgrad  1='(1) Yes, graduated from high school'
                  2='(2) No, did not graduate from high school' ;
  VALUE iihsgrad  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irworkst  1='(1) Working full-time, 35 hours or more a week'
                  2='(2) Working part-time, less than 35 hours a week'
                  3='(3) Have job but out: illness/leave/furlough'
                  4='(4) Unemployed or laid off and looking for work'
                  5='(5) Unemployed and not looking for work'
                  6='(6) Full-time homemaker only' 7='(7) In school only' 8='(8) Retired'
                  9='(9) Disabled, not able to work' 10='(10) Other, in labor force'
                  11='(11) Other, not in labor force' ;
  VALUE iiworkst  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinsur   1='(1) Yes, respondent does have health insurance'
                  2='(2) No, respondent does not have health insurance' ;
  VALUE iiinsur   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irearn    1='(1) No personal earnings' 2='(2) Yearly under $5,000'
                  3='(3) Yearly $5,000 to $6,999' 4='(4) Yearly $7,000 to $8,999'
                  5='(5) Yearly $9,000 to $11,999' 6='(6) Yearly $12,000 to $14,999'
                  7='(7) Yearly $15,000 to $19,999' 8='(8) Yearly $20,000 to $24,999'
                  9='(9) Yearly $25,000 to $29,999'
                  10='(10) Yearly $30,000 to $39,999'
                  11='(11) Yearly $40,000 to $49,999'
                  12='(12) Yearly $50,000 to $74,999'
                  13='(13) Yearly more than $75,000' 99='(99) LEGITIMATE SKIP' ;
  VALUE iiearn    1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc47f  1='(1) No personal earnings' 2='(2) Yearly under $5,000'
                  3='(3) Yearly $5,000 to $6,999' 4='(4) Yearly $7,000 to $8,999'
                  5='(5) Yearly $9,000 to $11,999' 6='(6) Yearly $12,000 to $14,999'
                  7='(7) Yearly $15,000 to $19,999' 8='(8) Yearly $20,000 to $24,999'
                  9='(9) Yearly $25,000 to $29,999'
                  10='(10) Yearly $30,000 to $39,999'
                  11='(11) Yearly $40,000 to $49,999'
                  12='(12) Yearly $50,000 to $74,999'
                  13='(13) Yearly more than $75,000' 99='(99) LEGITIMATE SKIP' ;
  VALUE iiinc47f  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc48a  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iiinc48a  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc49a  999999='(999999) LEGITIMATE SKIP' ;
  VALUE iiinc49a  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc48b  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iiinc48b  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc49b  999999='(999999) LEGITIMATE SKIP' ;
  VALUE iiinc49b  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc48c  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iiinc48c  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc49c  999999='(999999) LEGITIMATE SKIP' ;
  VALUE iiinc49c  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc48d  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iiinc48d  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc49d  999999='(999999) LEGITIMATE SKIP' ;
  VALUE iiinc49d  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc48e  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iiinc48e  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc49e  999999='(999999) LEGITIMATE SKIP' ;
  VALUE iiinc49e  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc48f  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iiinc48f  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc49f  999999='(999999) LEGITIMATE SKIP' ;
  VALUE iiinc49f  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc48g  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iiinc48g  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc49g  999999='(999999) LEGITIMATE SKIP' ;
  VALUE iiinc49g  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc48h  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iiinc48h  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc49h  999999='(999999) LEGITIMATE SKIP' ;
  VALUE iiinc49h  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc48i  1='(1) Yes' 2='(2) No' 999999='(999999) LEGITIMATE SKIP' ;
  VALUE iiinc48i  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE irinc49i  999999='(999999) LEGITIMATE SKIP' ;
  VALUE iiinc49i  1='(1) Questionnaire data' 2='(2) Logically imputed'
                  3='(3) Statistically imputed' 9='(9) LEGITIMATE SKIP' ;
  VALUE iralcrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but < 6 months ago'
                  3='(3) 6+ months ago but < 1 year ago'
                  4='(4) 1+ years ago but < 3 years ago' 5='(5) 3+ years ago'
                  9='(9) Never used alcohol' ;
  VALUE iialcrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irmjrc    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but < 1 month ago'
                  3='(3) 1+ months ago but < 6 months ago'
                  4='(4) 6+ months ago but < 1 year ago'
                  5='(5) 1+ years ago but < 3 years ago' 6='(6) 3+ years ago'
                  9='(9) Never used marijuana' ;
  VALUE iimjrc    1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE ircocrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but < 1 month ago'
                  3='(3) 1+ months ago but < 6 months ago'
                  4='(4) 6+ months ago but < 1 year ago'
                  5='(5) 1+ years ago but < 3 years ago' 6='(6) 3+ years ago'
                  9='(9) Never used cocaine' ;
  VALUE iicocrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irsedrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but < 6 months ago'
                  3='(3) 6+ months ago but < 1 year ago'
                  4='(4) 1+ years ago but < 3 years ago' 5='(5) 3+ years ago'
                  9='(9) Never used sedatives' ;
  VALUE iisedrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irtrnrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but < 6 months ago'
                  3='(3) 6+ months ago but < 1 year ago'
                  4='(4) 1+ years ago but < 3 years ago' 5='(5) 3+ years ago'
                  9='(9) Never used tranquilizers' ;
  VALUE iitrnrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irstmrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but < 6 months ago'
                  3='(3) 6+ months ago but < 1 year ago'
                  4='(4) 1+ years ago but < 3 years ago' 5='(5) 3+ years ago'
                  9='(9) Never used stimulants' ;
  VALUE iistmrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE iranlrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but < 6 months ago'
                  3='(3) 6+ months ago but < 1 year ago'
                  4='(4) 1+ years ago but < 3 years ago' 5='(5) 3+ years ago'
                  9='(9) Never used analgesics' ;
  VALUE iianlrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE ircigrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but < 6 months ago'
                  3='(3) 6+ months ago but < 1 year ago'
                  4='(4) 1+ years ago but < 3 years ago' 5='(5) 3+ years ago'
                  9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irotbrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but < 6 months ago'
                  3='(3) 6+ months ago but < 1 year ago'
                  4='(4) 1+ years ago but < 3 years ago' 5='(5) 3+ years ago'
                  9='(9) Never used smokeless tobacco' ;
  VALUE iiotbrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irinhrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but < 1 month ago'
                  3='(3) 1+ months ago but < 6 months ago'
                  4='(4) 6+ months ago but < 1 year ago'
                  5='(5) 1+ years ago but < 3 years ago' 6='(6) 3+ years ago'
                  9='(9) Never used inhalants' ;
  VALUE iiinhrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE ircrkrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but < 1 month ago'
                  3='(3) 1+ months ago but < 6 months ago'
                  4='(4) 6+ months ago but < 1 year ago'
                  5='(5) 1+ years ago but < 3 years ago' 6='(6) 3+ years ago'
                  9='(9) Never used crack' ;
  VALUE iicrkrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irhalrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but < 6 months ago'
                  3='(3) 6+ months ago but < 1 year ago'
                  4='(4) 1+ years ago but < 3 years ago' 5='(5) 3+ years ago'
                  9='(9) Never used hallucinogens' ;
  VALUE iihalrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irherrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but < 6 months ago'
                  3='(3) 6+ months ago but < 1 year ago'
                  4='(4) 1+ years ago but < 3 years ago' 5='(5) 3+ years ago'
                  9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irpcprc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but < 6 months ago'
                  3='(3) 6+ months ago but < 1 year ago'
                  4='(4) 1+ years ago but < 3 years ago' 5='(5) 3+ years ago'
                  9='(9) Never used PCP' ;
  VALUE iipcprc   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE iricerc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but < 1 month ago'
                  3='(3) 1+ months ago but < 6 months ago'
                  4='(4) 6+ months ago but < 1 year ago' 6='(6) 3+ years ago'
                  9='(9) Never used ice' ;
  VALUE iiicerc   1='(1) Questionnaire data' 2='(2) Statistically Imputed data' ;
  VALUE iralcfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iialcfq   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irmjfq    1='(1) Used several times per day in past year'
                  2='(2) Used daily in past year'
                  3='(3) Used almost daily in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used several times per month in past year'
                  6='(6) Used 1-2 times per month in past year'
                  7='(7) Used every other month in past year'
                  8='(8) Used 3-5 times in past year'
                  9='(9) Used 1-2 times in past year'
                  10='(10) Never used or did not use in the past year' ;
  VALUE iimjfq    1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE ircocfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times per month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iicocfq   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irsedfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iisedfq   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irtrnfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iitrnfq   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irstmfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iistmfq   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE iranlfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iianlfq   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irotbfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iiotbfq   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irinhfq   1='(1) Use daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iiinhfq   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE irhalfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iihalfq   1='(1) Questionnaire data' 2='(2) Statistically imputed data' ;
  VALUE catage    1='(1) 12-17 years (IRAGE = 12-17)'
                  2='(2) 18-25 years (IRAGE = 18-25)'
                  3='(3) 26-34 years (IRAGE = 26-34)' 4='(4) 35+ years (IRAGE > 34)' ;
  VALUE catag2ff  1='(1) 12-17 years (CATAGE = 1)' 2='(2) 18-25 years (CATAGE = 2)'
                  3='(3) 26+ years (CATAGE = 3-4)' ;
  VALUE race      1='(1) White (IRRACE = 4 and IRHOIND = 2)'
                  2='(2) Black (IRRACE = 3 and IRHOIND = 2)'
                  3='(3) Hispanic (IRHOIND = 1)'
                  4='(4) Other (IRRACE = 1-2 and IRHOIND = 2)' ;
  VALUE educcatf  1='(1) Less than high school (IREDUC=0-11 and I'
                  2='(2) High school graduate (IREDUC = 12 and IR'
                  3='(3) Some college (IREDUC = 13-15 and IRAGE ='
                  4='(4) College graduate (IREDUC = 16-17 and IRA'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE empstatf  1='(1) Full-time (IRWORKST = 1,3 and IRAGE => 1'
                  2='(2) Part-time (IRWORKST = 2 and IRAGE => 18)'
                  3='(3) Unemployed (IRWORKST = 4,5,10 and IRAGE'
                  4='(4) Other (IRWORKST = 6-9,11 and IRAGE => 18'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE totinc    9999999='(9999999) LEGITIMATE SKIP' ;
  VALUE totcat    1='(1) No personal earnings' 2='(2) Yearly under $5,000'
                  3='(3) Yearly $5,000 to $6,999' 4='(4) Yearly $7,000 to $8,999'
                  5='(5) Yearly $9,000 to $11,999' 6='(6) Yearly $12,000 to $14,999'
                  7='(7) Yearly $15,000 to $19,999' 8='(8) Yearly $20,000 to $24,999'
                  9='(9) Yearly $25,000 to $29,999'
                  10='(10) Yearly $30,000 to $39,999'
                  11='(11) Yearly $40,000 to $49,999'
                  12='(12) Yearly $50,000 to $74,999'
                  13='(13) Yearly more than $75,000' 99='(99) LEGITIMATE SKIP' ;
  VALUE faminc    1='(1) Yearly $0 to $8,999 (TOTCAT = 1-4)'
                  2='(2) Yearly $9,000 to $19,999 (TOTCAT = 5-7)'
                  3='(3) Yearly $20,000 to $39,999 (TOTCAT = 8-10'
                  4='(4) Yearly $40,000 to 74,999 (TOTCAT = 11-1'
                  5='(5) Yearly more than $75,000 (TOTCAT = 13)'
                  6='(6) LEGITIMATE SKIP (TOTCAT = 99)' ;
  VALUE perearn   1='(1) No personal earnings (IREARN = 1)'
                  2='(2) Yearly under $5,000 to $8,999 (IREARN ='
                  3='(3) Yearly $9,000 to $19,999 (IREARN = 5-7)'
                  4='(4) Yearly $20,000 to 39,999 (IREARN = 8-10)'
                  5='(5) Yearly more than $40,000 (IREARN = 11-13'
                  6='(6) LEGITIMATE SKIP (IRAGE < 18)' ;
  VALUE halflag   0='(0) Never used (IRHALRC = 9)' 1='(1) Ever used (IRHALRC = 1-5)' ;
  VALUE halyr     0='(0) Did not use in the past year (IRHALRC ='
                  1='(1) Used within the past year (IRHALRC = 1-3' ;
  VALUE halmon    0='(0) Did not use in the past month (IRHALRC ='
                  1='(1) Used within the past month (IRHALRC = 1)' ;
  VALUE pcpflag   0='(0) Never used (IRPCPRC = 9)' 1='(1) Ever used (IRPCPRC = 1,5)' ;
  VALUE pcpyr     0='(0) Did not use in the past year (IRPCPRC ='
                  1='(1) Used within the past year (IRPCPRC = 1-3' ;
  VALUE pcpmon    0='(0) Did not use in the past month (IRPCPRC ='
                  1='(1) Used within the past month (IRPCPRC = 1)' ;
  VALUE stmflag   0='(0) Never used (IRSTMRC = 9)' 1='(1) Ever used (IRSTMRC = 1-5)' ;
  VALUE stmyr     0='(0) Did not use in the past year (IRSTMRC ='
                  1='(1) Used within the past year (IRSTMRC = 1-3' ;
  VALUE stmmon    0='(0) Did not use in the past month (IRSTMRC ='
                  1='(1) Used within the past month (IRSTMRC = 1)' ;
  VALUE sedflag   0='(0) Never used (IRSEDRC = 9)' 1='(1) Ever used (IRSEDRC = 1-5)' ;
  VALUE sedyr     0='(0) Did not use in the past year (IRSEDRC ='
                  1='(1) Used within the past year (IRSEDRC = 1-3' ;
  VALUE sedmon    0='(0) Did not use in the past month (IRSEDRC ='
                  1='(1) Used within the past month (IRSEDRC = 1)' ;
  VALUE trqflag   0='(0) Never used (IRTRNRC = 9)' 1='(1) Ever used (IRTRNRC = 1-5)' ;
  VALUE trqyr     0='(0) Did not use in the past year (IRTRNRC ='
                  1='(1) Used within the past year (IRTRNRC = 1-3' ;
  VALUE trqmon    0='(0) Did not use in the past month (IRTRNRC ='
                  1='(1) Used within the past month (IRTRNRC = 1)' ;
  VALUE anlflag   0='(0) Never used (IRANLRC = 9)' 1='(1) Ever used (IRANLRC = 1-5)' ;
  VALUE anlyr     0='(0) Did not use in the past year (IRANLRC ='
                  1='(1) Used within the past year (IRANLRC = 1-3' ;
  VALUE anlmon    0='(0) Did not use in the past month (IRANLRC ='
                  1='(1) Used within the past month (IRANLRC = 1)' ;
  VALUE alcflag   0='(0) Never used (IRALCRC = 9)' 1='(1) Ever used (IRALCRC = 1-5)' ;
  VALUE alcyr     0='(0) Did not use in the past year (IRALCRC ='
                  1='(1) Used within the past year (IRALCRC = 1-3' ;
  VALUE alcmon    0='(0) Did not use in the past month (IRALCRC ='
                  1='(1) Used within the past month (IRALCRC = 1)' ;
  VALUE cigflag   0='(0) Never used (IRCIGRC = 9)' 1='(1) Ever used (IRCIGRC = 1-5)' ;
  VALUE cigyr     0='(0) Did not use in the past year (IRCIGRC ='
                  1='(1) Used within the past year (IRCIGRC = 1-3' ;
  VALUE cigmon    0='(0) Did not use in the past month (IRCIGRC ='
                  1='(1) Used within the past month (IRCIGRC = 1)' ;
  VALUE smkflag   0='(0) Never used (IROTBRC = 9)' 1='(1) Ever used (IROTBRC = 1-5)' ;
  VALUE smkyr     0='(0) Did not use in the past year (IROTBRC ='
                  1='(1) Used within the past year (IROTBRC = 1-3' ;
  VALUE smkmon    0='(0) Did not use in the past month (IROTBRC ='
                  1='(1) Used within the past month (IROTBRC = 1)' ;
  VALUE herflag   0='(0) Never used (IRHERRC = 9)' 1='(1) Ever used (IRHERRC = 1-5)' ;
  VALUE heryr     0='(0) Did not use in the past year (IRHERRC ='
                  1='(1) Used within the past year (IRHERRC = 1-3' ;
  VALUE hermon    0='(0) Did not use in the past month (IRHERRC ='
                  1='(1) Used within the past month (IRHERRC = 1)' ;
  VALUE mrjflag   0='(0) Never used (IRMJRC = 9)' 1='(1) Ever used (IRMJRC = 1-6)' ;
  VALUE mrjyr     0='(0) Did not use in the past year (IRMJRC = 5'
                  1='(1) Used within the past year (IRMJRC = 1-4)' ;
  VALUE mrjmon    0='(0) Did not use in the past month (IRMJRC ='
                  1='(1) Used within the past month (IRMJRC = 1-2' ;
  VALUE cocflag   0='(0) Never used (IRCOCRC = 9)' 1='(1) Ever used (IRCOCRC = 1-6)' ;
  VALUE cocyr     0='(0) Did not use in the past year (IRCOCRC ='
                  1='(1) Used within the past year (IRCOCRC = 1-4' ;
  VALUE cocmon    0='(0) Did not use in the past month (IRCOCRC ='
                  1='(1) Used within the past month (IRCOCRC = 1-' ;
  VALUE crkflag   0='(0) Never used (IRCRKRC = 9)' 1='(1) Ever used (IRCRKRC = 1-6)' ;
  VALUE crkyr     0='(0) Did not use in the past year (IRCRKCR= 5'
                  1='(1) Used within the past year (IRCRKRC = 1-4' ;
  VALUE crkmon    0='(0) Did not use in the past month (IRCRKRC ='
                  1='(1) Used within the past month (IRCRKRC = 1-' ;
  VALUE inhflag   0='(0) Never used (IRINHRC = 9)' 1='(1) Ever used (IRINHRC = 1-6)' ;
  VALUE inhyr     0='(0) Did not use in the past year (IRINHRC ='
                  1='(1) Used within the past year (IRINHRC = 1-4' ;
  VALUE inhmon    0='(0) Did not use in the past month (IRINHRC ='
                  1='(1) Used within the past month (IRINHRC = 1-' ;
  VALUE needlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE' ;
  VALUE ndl90rec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE' ;
  VALUE ndl90rcf  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  81='(81) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE' ;
  VALUE nedflagf  0='(0) Never used (NDL90REC = 91,98)'
                  1='(1) Ever used (NDL90REC = 1-9)' ;
  VALUE nedyr2ff  0='(0) Did not use in the past year (NDL90REC=4'
                  1='(1) Used within the past year (NDL90REC=1-3,' ;
  VALUE halyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRHALFQ=1-' ;
  VALUE halmonf   0='(0) Did not use monthly/more past year (IRHA'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE halwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRH' ;
  VALUE stmyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRSTMFQ=1-' ;
  VALUE stmmonf   0='(0) Did not use monthly/more past year (IRST'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE stmwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRS' ;
  VALUE sedyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRSEDFQ=1-' ;
  VALUE sedmonf   0='(0) Did not use monthly/more past year (IRSE'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE sedwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRS' ;
  VALUE trqyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRTRNFQ=1-' ;
  VALUE trqmonf   0='(0) Did not use monthly/more past year (IRTR'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE trqwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRT' ;
  VALUE anlyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRANLFQ=1-' ;
  VALUE anlmonf   0='(0) Did not use monthly/more past year (IRAN'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE anlwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRA' ;
  VALUE alcyrf    0='(0) Never used or not used in past year (IRA'
                  1='(1) Any use within the past year (IRALCFQ=1-' ;
  VALUE alcmonf   0='(0) Did not use monthly/more past year (IRAL'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE alcwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more in past year (IRALCF' ;
  VALUE smkyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IROTBFQ=1-' ;
  VALUE smkmonf   0='(0) Did not use monthly/more past year (IROT'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE smkwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRO' ;
  VALUE mrjyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRMJFQ=1-9' ;
  VALUE mrjmonf   0='(0) Did not use monthly/more past year (IRMJ'
                  1='(1) Used monthly or more in past year (IRMJF' ;
  VALUE mrjwkf    0='(0) Did not use weekly/more past year (IRMJF'
                  1='(1) Used weekly or more in past year (IRMJFQ' ;
  VALUE cocyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRCOCFQ =' ;
  VALUE cocmonf   0='(0) Did not use monthly/more past year (IRCO'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE cocwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRC' ;
  VALUE inhyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRINHFQ=1-' ;
  VALUE inhmonf   0='(0) Did not use monthly/more past year (IRIN'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE inhwkf    0='(0) Did not use weekly or more past year (IR'
                  1='(1) Used weekly or more often past year (IRI' ;
  VALUE psyflagf  0='(0) Never used (ALL SOURCE VARIABLES = 9)'
                  1='(1) Ever used (ANY SOURCE VARIABLE < 9)' ;
  VALUE psyyr2ff  0='(0) Did not use within past year (ALL SOURCE'
                  1='(1) Used in past year (ANY SOURCE VARIABLE <' ;
  VALUE psymon2f  0='(0) Did not use in past month (ALL SOURCE VA'
                  1='(1) Used in past month (ANY SOURCE VARIABLE' ;
  VALUE sumflag   0='(0) Never used (ALL SOURCE VARIABLES = 0)'
                  1='(1) Ever used (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumyr     0='(0) Did not use in past year (ALL SOURCE VAR'
                  1='(1) Used in past year (ANY SOURCE VARIABLE =' ;
  VALUE summon    0='(0) Did not use in past month (ALL SOURCE VA'
                  1='(1) Used in past month (ANY SOURCE VARIABLE' ;
  VALUE mjoflag   0='(0) Never used MJ/has used both MJ & another illict drug'
                  1='(1) Marijuana is only (illicit) drug ever used' ;
  VALUE mjoyr2ff  0='(0) MJ not used past yr/Used MJ & othr drug past yr'
                  1='(1) Marijuana is only (illicit) drug in past year' ;
  VALUE mjomon2f  0='(0) MJ not used past mnth/Used MJ & othr drug past mo'
                  1='(1) Marijuana only (illicit) drug in past month' ;
  VALUE aeros2ff  0='(0) Never inhaled (AEROS = 2,81,91,98)'
                  1='(1) Ever inhaled (AEROS = 1,3)' ;
  VALUE alcdaysf  1='(1) None or never used alcohol (ALCDAYS = 0,'
                  2='(2) 1-2 days (ALCDAYS = 1-2)' 3='(3) 3-4 days (ALCDAYS = 3-4)'
                  4='(4) 5-19 days (ALCDAYS = 5-19)'
                  5='(5) 20-30 days (ALCDAYS = 20-30)' ;
  VALUE alcday0f  1='(1) None or never used alcohol (ALCDAYS2 = 1'
                  2='(2) 1-4 days (ALCDAYS2 = 2-3)' 3='(3) 5-19 days (ALCDAYS2 = 4)'
                  4='(4) 20-30 days (ALCDAYS2 = 5)' ;
  VALUE alcmon2f  1='(1) Did not use in the past month (ALCMON ='
                  2='(2) Used within the past month (ALCMON = 1)' ;
  VALUE amylnitf  0='(0) Never inhaled (AMYLNIT = 2,81,91,98)'
                  1='(1) Ever inhaled (AMYLNIT = 1,3)' ;
  VALUE avcig2ff  1='(1) None or never smoked cigarettes (AVCIG=8'
                  2='(2) Currently smoke < a pack per day (AVCIG'
                  3='(3) Currently smoke a pack or more per day (' ;
  VALUE avcig3ff  0='(0) None/never/< pack a day (AVCIG=1-3,81,89'
                  1='(1) Currently smoke a pack or more per day (' ;
  VALUE cigmon2f  1='(1) Did not use in past month (CIGMON = 0)'
                  2='(2) Used within past month (CIGMON = 1)' ;
  VALUE cleflu2f  0='(0) Never inhaled (CLEFLU = 2,81,91,98)'
                  1='(1) Ever inhaled (CLEFLU = 1,3)' ;
  VALUE cociv2ff  0='(0) Never/no use in pst 12 mos (COCIV=2,81,8'
                  1='(1) Injected in the past 12 months (COCIV =' ;
  VALUE cocnewaf  0='(0) Never/no use in pst 12 mos (COCNEWA=81,8'
                  1='(1) Used other ways past 12 months (COCNEWA' ;
  VALUE cocsni0f  0='(0) Never/no use pst 12 mos(COCSNIFF=2,81,83'
                  1='(1) Sniffed/snorted in past 12 months (COCSN' ;
  VALUE cocswalf  0='(0) Never/no use pst 12 mos(COCSWAL=2,81,83,'
                  1='(1) Swallowed/drank in past 12 months (COCSW' ;
  VALUE coctot2f  1='(1) Never used cocaine (COCTOT = 81,91)'
                  2='(2) 1-2 times (COCTOT = 1)' 3='(3) 3-10 times (COCTOT = 2,3)'
                  4='(4) 11-99 times (COCTOT = 4,5)'
                  5='(5) 100 or more times (COCTOT = 6,7)'
                  6='(6) Unknown (COCTOT = 85,98)' ;
  VALUE coctot3f  1='(1) 1-2 times (COCTOT2 = 2)' 2='(2) 3-10 times (COCTOT2 = 3)'
                  3='(3) 11-99 times (COCTOT2 = 4)'
                  4='(4) 100 or more times (COCTOT2 = 5)'
                  5='(5) Never used cocaine (COCTOT2 = 1)' ;
  VALUE dcotsmsa  1='(1) DC MSA (DC=1,2)'
                  2='(2) Large SMSAs not including DC (POPDEN=1 a' 3='(3) Other' ;
  VALUE drinkerf  0='(0) Never/no alcohol use (ALCMON=0 and DR5DA'
                  1='(1) Alcohol use (ALCMON = 1 and DR5DAY = 0-3' ;
  VALUE drunkyrf  0='(0) Unknown (DRUNKYR = 85,96,97,98)'
                  1='(1) Drunk more than twice a month (DRUNKYR ='
                  2='(2) Drunk twice a month or less (DRUNKYR = 5'
                  3='(3) Never drunk in past year (DRUNKYR = 9)' ;
  VALUE ether2ff  0='(0) Never inhaled (ETHER = 2,81,91,98)'
                  1='(1) Ever inhaled (ETHER = 1,3)' ;
  VALUE freebasf  0='(0) Never/no use pst 12 mos (FREEBASE=2,81,8'
                  1='(1) Freebased in past 12 months (FREEBASE =' ;
  VALUE gas2ffff  0='(0) Never inhaled (GAS = 2,81,91,98)'
                  1='(1) Ever inhaled (GAS = 1,3)' ;
  VALUE glue2fff  0='(0) Never inhaled (GLUE = 2,81,91,98)'
                  1='(1) Ever inhaled (GLUE = 1,3)' ;
  VALUE gndlshrf  0='(0) No (GNNDLSHR=2,81,91,98)' 1='(1) Yes (GNNDLSHR=1)' ;
  VALUE hvydrk2f  0='(0) Never/no heavy use (DR5DAY=0-4,81,91)'
                  1='(1) Heavy alcohol use (DR5DAY = 5-30)' ;
  VALUE lsd2ffff  0='(0) Never used hallucinogens (LSD = 2,81,91,'
                  1='(1) Ever used LSD (LSD = 1)' ;
  VALUE mesc2fff  0='(0) Never used hallucinogens (MESC = 2,81,91'
                  1='(1) Ever used Mescaline (MESC = 1)' ;
  VALUE mjdy30af  1='(1) None or never used marijuana (MJDAY30A ='
                  2='(2) 1-2 days (MJDAY30A = 1-2)' 3='(3) 3-4 days (MJDAY30A = 3-4)'
                  4='(4) 5-19 days (MJDAY30A = 5-19)'
                  5='(5) 20-30 days (MJDAY30A = 20-30)'
                  6='(6) Unknown (MJDAY30A = 85,98)' ;
  VALUE mjdy300f  1='(1) 1-2 days (MJDAY30A2 = 2)' 2='(2) 3-4 days (MJDAY30A2 = 3)'
                  3='(3) 5-19 days (MJDAY30A2 = 4)'
                  4='(4) 20-30 days (MJDAY30A2 = 5)'
                  5='(5) None or never used marijuana (MJDAY30A2' ;
  VALUE mjtot2ff  1='(1) Never used marijuana (MJTOT = 81,91)'
                  2='(2) 1-2 times (MJTOT = 1)' 3='(3) 3-10 times (MJTOT = 2,3)'
                  4='(4) 11-99 times (MJTOT = 4,5)'
                  5='(5) 100 or more times (MJTOT = 6,7)'
                  6='(6) Unknown (MJTOT = 85,96,97,98)' ;
  VALUE mjtot3ff  1='(1) 1-2 times (MJTOT2 = 2)' 2='(2) 3-10 times (MJTOT2 = 3)'
                  3='(3) 11-99 times (MJTOT2 = 4)'
                  4='(4) 100 or more times (MJTOT2 = 5)'
                  5='(5) Never used marijuana (MJTOT2 = 1)' ;
  VALUE mrjmon2f  1='(1) Did not use in past month (MRJMON = 0)'
                  2='(2) Used within the past month (MRJMON = 1)' ;
  VALUE nedfla0f  0='(0) Never used (NDL90RC2=81,91,98)'
                  1='(1) Ever used (NDL90RCC2=1-9)' ;
  VALUE nitoxidf  0='(0) Never inhaled (NITOXID = 2,81,91,98)'
                  1='(1) Ever inhaled (NITOXID = 1,3)' ;
  VALUE notmarj   0='(0) No (ALL SOURCE VARIABLES = 0)'
                  1='(1) Yes (ANY SOURCE VARIABLES = 1)' ;
  VALUE peyote2f  0='(0) Never used hallucinogens (PEYOTE = 2,81,'
                  1='(1) Ever used Peyote (PEYOTE = 1)' ;
  VALUE psilcy2f  0='(0) Never used hallucinogens (PSILCY = 2,81,'
                  1='(1) Ever used Psilocybin (PSILCY = 1)' ;
  VALUE racesex   1='(1) White male (SEX = 1 and RACE = 1)'
                  2='(2) Black male (SEX = 1 and RACE = 2)'
                  3='(3) Hispanic male (SEX = 1 and RACE = 3)'
                  4='(4) White female (SEX = 2 and RACE = 1)'
                  5='(5) Black female (SEX = 2 and RACE = 2)'
                  6='(6) Hispanic female (SEX = 2 and RACE = 3)' ;
  VALUE solventf  0='(0) Never inhaled (SOLVENT = 2,81,91,98)'
                  1='(1) Ever inhaled (SOLVENT = 1,3)' ;
  VALUE sppaintf  0='(0) Never inhaled (SPPAINT = 2,81,91,98)'
                  1='(1) Ever inhaled (SPPAINT = 1,3)' ;
  VALUE iras13ff  1='(1) Never used any of the substances listed'
                  2='(2) Used one or more of the listed substance' ;
  VALUE irdep     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irdep1ff  112='(112) Restoril'
                  116='(116) Methaqualone (including Sopor, Quaalude)'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  121='(121) USED SEDATIVE, DONT KNOW NAME' 123='(123) Unisom'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine' 339='(339) Amphetamines (speed)' 348='(348) Crystal'
                  401='(401) Darvon' 501='(501) Gasoline or lighter fluids'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 808='(808) All of the ones Ive tried'
                  812='(812) Cigars' 813='(813) Cigarettes, Tobacco' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep2ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers' 201='(201) Valium'
                  209='(209) Xanax' 332='(332) Ephedrine' 336='(336) Diet pills'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 999='(999) LEGITIMATE SKIP' ;
  VALUE irdep3ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (Speed or Crank)'
                  409='(409) Tylenol with Codeine' 801='(801) OTHER Drugs, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep4ff  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irarg     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irarg1ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers' 123='(123) Unisom'
                  209='(209) Xanax' 322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine' 336='(336) Diet pills' 348='(348) Crystal'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens'
                  601='(601) LSD (acid, white lightning)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 808='(808) All of the ones Ive tried' 812='(812) Cigars'
                  813='(813) Cigarettes, Tobacco'
                  816='(816) Smokeless tobacco - snuff/chewing' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg2ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers' 201='(201) Valium'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 336='(336) Diet pills'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 813='(813) Cigarettes, Tobacco'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg3ff  201='(201) Valium' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  409='(409) Tylenol with Codeine' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE iraln     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE iraln1ff  116='(116) Methaqualone (including Sopor, Quaalude)'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  121='(121) USED SEDATIVE, DONT KNOW NAME' 123='(123) Unisom'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 808='(808) All of the ones Ive tried'
                  813='(813) Cigarettes, Tobacco' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE iraln2ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  336='(336) Diet pills' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln3ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE iranx1ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  122='(122) Sleep Aid' 201='(201) Valium' 209='(209) Xanax'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME'
                  329='(329) Speckled Eggs, Robins Eggs' 332='(332) Ephedrine'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed)' 348='(348) Crystal'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens' 513='(513) Tulio Osica'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 812='(812) Cigars'
                  813='(813) Cigarettes, Tobacco' 814='(814) Caffeine' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx2ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 336='(336) Diet pills'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 999='(999) LEGITIMATE SKIP' ;
  VALUE iranx3ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)' 803='(803) Marijuana'
                  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irhlt1ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME'
                  339='(339) Amphetamine (speed)' 348='(348) Crystal' 426='(426) Fiorinal'
                  430='(430) Aspirin, Ecotrine' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, Tobacco' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt2ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt3ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 999='(999) LEGITIMATE SKIP' ;
  VALUE irntk     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irntk1ff  116='(116) Methaqualone (including Sopor, Quaalude)'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  122='(122) Sleep Aid' 201='(201) Valium' 209='(209) Xanax'
                  222='(222) USED TRANQUILIZER, DONT KNOW NAME'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 348='(348) Crystal'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 812='(812) Cigars'
                  813='(813) Cigarettes, Tobacco' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE irntk2ff  24='(24) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  409='(409) Tylenol with Codeine' 417='(417) Morphine'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 999='(999) LEGITIMATE SKIP' ;
  VALUE irntk3ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 603='(603) Mescaline'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irntk4ff  803='(803) Marijuana' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irups1ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  122='(122) Sleep Aid' 201='(201) Valium'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 332='(332) Ephedrine'
                  336='(336) Diet pills' 348='(348) Crystal' 409='(409) Tylenol with Codeine'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, Felt-tip pens'
                  601='(601) LSD (acid, white lightning)'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 813='(813) Cigarettes, Tobacco'
                  814='(814) Caffeine' 815='(815) Coffee' 817='(817) Hardstuff' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irups2ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  336='(336) Diet pills' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irups3ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irlsw1ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers' 201='(201) Valium'
                  222='(222) USED TRANQUILIZER, DONT KNOW NAME'
                  322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 348='(348) Crystal'
                  409='(409) Tylenol with Codeine'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 813='(813) Cigarettes, Tobacco'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw2ff  201='(201) Valium' 324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  601='(601) LSD (acid, white lightning)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw3ff  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE irssp1ff  116='(116) Methaqualone (including Sopor, Quaalude)'
                  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  122='(122) Sleep Aid' 322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 348='(348) Crystal'
                  353='(353) No-Doz' 511='(511) Markers, Felt-tip pens'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  804='(804) Hashish' 805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 813='(813) Cigarettes, Tobacco'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE irssp2ff  702='(702) Heroin' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp3ff  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE ircpe1ff  120='(120) OTHER Sedative, NOT SPECIFIED, Downers'
                  122='(122) Sleep Aid' 322='(322) Methamphetamine (Speed or Crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 348='(348) Crystal'
                  426='(426) Fiorinal' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  702='(702) Heroin' 803='(803) Marijuana' 804='(804) Hashish'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  808='(808) All of the ones Ive tried' 813='(813) Cigarettes, Tobacco1'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe2ff  201='(201) Valium' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  702='(702) Heroin' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe3ff  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRAS13 = 1)' ;
  VALUE iremg1ff  603='(603) Mescaline' 702='(702) Heroin' 803='(803) Marijuana' 804='(804) Hashish'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE iremg2ff  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg3ff  806='(806) Crack' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE iremg4ff  601='(601) LSD (acid, white lightning)' 999='(999) LEGITIMATE SKIP' ;
  VALUE anyprob   0='(0) No' 1='(1) Yes' ;
  VALUE twoprob   0='(0) No' 1='(1) Yes' ;
  VALUE threprob  0='(0) No' 1='(1) Yes' ;
  VALUE alnalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE alncig2f  0='(0) No' 1='(1) Yes' ;
  VALUE alncoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE alnmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE argalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE argcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE argcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE argmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpealc2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpecig2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpecoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpemrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE depalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE depcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE depcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE depmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE emalc2ff  0='(0) No' 1='(1) Yes' ;
  VALUE emcig2ff  0='(0) No' 1='(1) Yes' ;
  VALUE emcoc2ff  0='(0) No' 1='(1) Yes' ;
  VALUE emmrj2ff  0='(0) No' 1='(1) Yes' ;
  VALUE hltalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE hltcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE hltcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE hltmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE upsalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE upscig2f  0='(0) No' 1='(1) Yes' ;
  VALUE upscoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE upsmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE prb1alc   0='(0) No' 1='(1) Yes' ;
  VALUE prb1cig   0='(0) No' 1='(1) Yes' ;
  VALUE prb1coc   0='(0) No' 1='(1) Yes' ;
  VALUE prb1mrj   0='(0) No' 1='(1) Yes' ;
  VALUE prb2alc   0='(0) No' 1='(1) Yes' ;
  VALUE prb2cig   0='(0) No' 1='(1) Yes' ;
  VALUE prb2coc   0='(0) No' 1='(1) Yes' ;
  VALUE prb2mrj   0='(0) No' 1='(1) Yes' ;
  VALUE prb3alc   0='(0) No' 1='(1) Yes' ;
  VALUE prb3cig   0='(0) No' 1='(1) Yes' ;
  VALUE prb3coc   0='(0) No' 1='(1) Yes' ;
  VALUE prb3mrj   0='(0) No' 1='(1) Yes' ;
  VALUE ircdalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwsalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwscig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwscoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwsmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcprobs  0='(0) No' 1='(1) Yes' ;
  VALUE cigprobs  0='(0) No' 1='(1) Yes' ;
  VALUE cocprobs  0='(0) No' 1='(1) Yes' ;
  VALUE mjprobs   0='(0) No' 1='(1) Yes' ;
  VALUE irnobooz  1='(1) No use of alcohol in the past year'
                  2='(2) Used alcohol in the past year' ;
  VALUE iralcabs  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcagg  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcalo  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcarg  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcbrk  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcdru  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcfrd  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralchig  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralchol  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcint  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcjob  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcmat  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcmor  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcqui  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcrel  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcrem  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralcsho  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE iralctos  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP (IRNOBOOZ = 1)' ;
  VALUE anyalc    0='(0) No' 1='(1) Yes' ;
  VALUE threalc   0='(0) No' 1='(1) Yes' ;
  VALUE alconlyl  0='(0) No' 1='(1) Yes (ALCFLAG=1 AND SUMFLAG=0)' ;
  VALUE alconlyy  0='(0) No' 1='(1) Yes (ALCYR=1 AND SUMYR=0)' ;
  VALUE alconlym  0='(0) No' 1='(1) Yes (ALCMON=1 AND SUMMON=0)' ;
  VALUE illonlyl  0='(0) No' 1='(1) Yes (SUMFLAG=1 AND ALCFLAG=0)' ;
  VALUE illonlyy  0='(0) No' 1='(1) Yes (SUMYR=1 AND ALCYR=0)' ;
  VALUE illonlym  0='(0) No' 1='(1) Yes (SUMMON=1 AND ALCMON=0)' ;
  VALUE mrjonlyl  0='(0) No' 1='(1) Yes (MJOFLAG=1 AND ALCFLAG=0)' ;
  VALUE mrjonlyy  0='(0) No' 1='(1) Yes (MJOYR2=1 AND ALCYR=0)' ;
  VALUE mrjonlym  0='(0) No' 1='(1) Yes (MJOMON2=1 AND ALCMON=0)' ;
  VALUE psyonlyl  0='(0) No' 1='(1) Yes (PSYFLAG2=1 & ALL OTHER SOURCE VAR' ;
  VALUE psyonlyy  0='(0) No' 1='(1) Yes (PSYYR2=1 & ALL OTHER SOURCE VARS=' ;
  VALUE psyonlym  0='(0) No' 1='(1) Yes (PSYMON2=1 & ALL OTHER SOURCE VARS' ;
  VALUE othonlyl  0='(0) No' 1='(1) Yes (1ST 3 SRCE VAR=0 & ANY OTHR SRCE' ;
  VALUE othonlyy  0='(0) No' 1='(1) Yes (1ST 3 SRCE VAR=0 & ANY OTHR SRCE' ;
  VALUE othonlym  0='(0) No' 1='(1) Yes (1ST 3 SRCE VAR=0 & ANY OTHR SRCE' ;
  VALUE alcilll   0='(0) No' 1='(1) Yes (ALCFLAG=1 AND SUMFLAG=1)' ;
  VALUE alcilly   0='(0) No' 1='(1) Yes (ALCYR=1 AND SUMYR=1)' ;
  VALUE alcillm   0='(0) No' 1='(1) Yes (ALCMON=1 AND SUMMON=1)' ;
  VALUE alcmrjl   0='(0) No' 1='(1) Yes (ALCFLAG,MRJFLAG=1& ALLOTHRSRCE VAR' ;
  VALUE alcmrjy   0='(0) No' 1='(1) Yes (ALCYR AND MRJYR=1& ALLOTHRSRCE VAR' ;
  VALUE alcmrjm   0='(0) No' 1='(1) Yes (ALCMON & MRJMON=1& ALLOTHRSRCEVA' ;
  VALUE alcpsyl   0='(0) No' 1='(1) Yes (ALCFLAG,PSYFLAG2=1& ALLOTHRSRCEVAR' ;
  VALUE alcpsyy   0='(0) No' 1='(1) Yes (ALCYR & PSYYR2=1& ALLOTHRSRCE VA' ;
  VALUE alcpsym   0='(0) No' 1='(1) Yes (ALCMON& PSYMON2=1& ALLOTHRSRCEVAR' ;
  VALUE alcothl   0='(0) No' 1='(1) Yes (ALCFLAG=1& NEXT 2VAR=0& ANYOTHRVA' ;
  VALUE alcothy   0='(0) No' 1='(1) Yes (ALCYR=1 & NEXT 2VAR=0 & ANY OTH' ;
  VALUE alcothm   0='(0) No' 1='(1) Yes (ALCMON=1& NEXT 2VAR=0& ANY OTHR V' ;
  VALUE sub1lif   0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub1yr    0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub1mon   0='(0) No' 1='(1) Yes (ONLY ONE OF THE SOURCE VARS=1)' ;
  VALUE sub2lif   0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub2yr    0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub2mon   0='(0) No' 1='(1) Yes (ONLY TWO OF THE SOURCE VARS=1)' ;
  VALUE sub3lif   0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
  VALUE sub3yr    0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
  VALUE sub3mon   0='(0) No' 1='(1) Yes (THREE OR MORE OF THE SOURCE VARS=1)' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CIGTRY >= 81) THEN CIGTRY = .;
   IF (CIG5PK >= 13) THEN CIG5PK = .;
   IF (CIGAGE >= 81) THEN CIGAGE = .;
   IF (CIGYRS >= 81) THEN CIGYRS = .;
   IF (PACKS >= 13) THEN PACKS = .;
   IF (CIGREC >= 13) THEN CIGREC = .;
   IF (AVCIG >= 13) THEN AVCIG = .;
   IF (CIGTIME >= 989) THEN CIGTIME = .;
   IF (SNUFREC >= 13) THEN SNUFREC = .;
   IF (OTHTOB >= 13) THEN OTHTOB = .;
   IF (ALCTRY >= 81) THEN ALCTRY = .;
   IF (ALCREC >= 13) THEN ALCREC = .;
   IF (ALCAGE >= 81) THEN ALCAGE = .;
   IF (ALCDAYS >= 81) THEN ALCDAYS = .;
   IF (NODR30A >= 81) THEN NODR30A = .;
   IF (DR5DAY >= 81) THEN DR5DAY = .;
   IF (MODR30A >= 81) THEN MODR30A = .;
   IF (MODR30DY >= 81) THEN MODR30DY = .;
   IF (ALCPAT >= 13) THEN ALCPAT = .;
   IF (DRUNKYR >= 13) THEN DRUNKYR = .;
   IF (ALCSED >= 13) THEN ALCSED = .;
   IF (ALCTRAN >= 13) THEN ALCTRAN = .;
   IF (ALCSTM >= 13) THEN ALCSTM = .;
   IF (ALCANAL >= 13) THEN ALCANAL = .;
   IF (ALCMJ >= 13) THEN ALCMJ = .;
   IF (ALCINH >= 13) THEN ALCINH = .;
   IF (ALCCOC >= 13) THEN ALCCOC = .;
   IF (ALCHAL >= 13) THEN ALCHAL = .;
   IF (ALCOPT >= 13) THEN ALCOPT = .;
   IF (ALCNONE >= 13) THEN ALCNONE = .;
   IF (ALCPREF >= 13) THEN ALCPREF = .;
   IF (NOSEDAT >= 13) THEN NOSEDAT = .;
   IF (BUTISOL >= 13) THEN BUTISOL = .;
   IF (BUTICAPS >= 13) THEN BUTICAPS = .;
   IF (AMYTAL >= 13) THEN AMYTAL = .;
   IF (MEBARAL >= 13) THEN MEBARAL = .;
   IF (PLACIDYL >= 13) THEN PLACIDYL = .;
   IF (DORIDEN >= 13) THEN DORIDEN = .;
   IF (NOLUDAR >= 13) THEN NOLUDAR = .;
   IF (NEMBUTAL >= 13) THEN NEMBUTAL = .;
   IF (SECONAL >= 13) THEN SECONAL = .;
   IF (TUINAL >= 13) THEN TUINAL = .;
   IF (DALMANE >= 13) THEN DALMANE = .;
   IF (RESTORIL >= 13) THEN RESTORIL = .;
   IF (HALCION >= 13) THEN HALCION = .;
   IF (AMOBARB >= 13) THEN AMOBARB = .;
   IF (PHENOBAR >= 13) THEN PHENOBAR = .;
   IF (METHAQ >= 13) THEN METHAQ = .;
   IF (CHHYD >= 13) THEN CHHYD = .;
   IF (PENTOB >= 13) THEN PENTOB = .;
   IF (SECOB >= 13) THEN SECOB = .;
   IF (SEDNEWA >= 991) THEN SEDNEWA = .;
   IF (SEDNEWB >= 991) THEN SEDNEWB = .;
   IF (SEDNEWC >= 991) THEN SEDNEWC = .;
   IF (SEDNOSP >= 13) THEN SEDNOSP = .;
   IF (SEDDKNAM >= 13) THEN SEDDKNAM = .;
   IF (SEDAGE >= 81) THEN SEDAGE = .;
   IF (SEDTOT >= 13) THEN SEDTOT = .;
   IF (SEDREC >= 13) THEN SEDREC = .;
   IF (SEDYRFRQ >= 13) THEN SEDYRFRQ = .;
   IF (AS3READ >= 13) THEN AS3READ = .;
   IF (NOTRANQ >= 13) THEN NOTRANQ = .;
   IF (VALIUM >= 13) THEN VALIUM = .;
   IF (LIBRIUM >= 13) THEN LIBRIUM = .;
   IF (LIMBTROL >= 13) THEN LIMBTROL = .;
   IF (MENRIUM >= 13) THEN MENRIUM = .;
   IF (SERAX >= 13) THEN SERAX = .;
   IF (TRANXENE >= 13) THEN TRANXENE = .;
   IF (ATIVAN >= 13) THEN ATIVAN = .;
   IF (CENTRAX >= 13) THEN CENTRAX = .;
   IF (XANAX >= 13) THEN XANAX = .;
   IF (PAXIPAM >= 13) THEN PAXIPAM = .;
   IF (BUSPAR >= 13) THEN BUSPAR = .;
   IF (MILTOWN >= 13) THEN MILTOWN = .;
   IF (EQUANIL >= 13) THEN EQUANIL = .;
   IF (DEPROL >= 13) THEN DEPROL = .;
   IF (VISTAR >= 13) THEN VISTAR = .;
   IF (ATARAX >= 13) THEN ATARAX = .;
   IF (DURRAX >= 13) THEN DURRAX = .;
   IF (DIAZEPAM >= 13) THEN DIAZEPAM = .;
   IF (SKLY >= 13) THEN SKLY = .;
   IF (MEPROB >= 13) THEN MEPROB = .;
   IF (TRNEWA >= 991) THEN TRNEWA = .;
   IF (TRNEWB >= 991) THEN TRNEWB = .;
   IF (TRNEWC >= 991) THEN TRNEWC = .;
   IF (TRNOSP >= 13) THEN TRNOSP = .;
   IF (TRDKNAM >= 13) THEN TRDKNAM = .;
   IF (TRANAGE >= 81) THEN TRANAGE = .;
   IF (TRANTOT >= 13) THEN TRANTOT = .;
   IF (TRANREC >= 13) THEN TRANREC = .;
   IF (TRNYRFRQ >= 13) THEN TRNYRFRQ = .;
   IF (AS4READ >= 13) THEN AS4READ = .;
   IF (NOSTIMS >= 13) THEN NOSTIMS = .;
   IF (DEXED >= 13) THEN DEXED = .;
   IF (DEXAMYL >= 13) THEN DEXAMYL = .;
   IF (ESKAT >= 13) THEN ESKAT = .;
   IF (BENZ >= 13) THEN BENZ = .;
   IF (BIPHET >= 13) THEN BIPHET = .;
   IF (DESOXYN >= 13) THEN DESOXYN = .;
   IF (TENUATE >= 13) THEN TENUATE = .;
   IF (TEPANIL >= 13) THEN TEPANIL = .;
   IF (DIDREX >= 13) THEN DIDREX = .;
   IF (PLEGINE >= 13) THEN PLEGINE = .;
   IF (PRELUDIN >= 13) THEN PRELUDIN = .;
   IF (IONAMIN >= 13) THEN IONAMIN = .;
   IF (FASTIN >= 13) THEN FASTIN = .;
   IF (PONDIMIN >= 13) THEN PONDIMIN = .;
   IF (VORANIL >= 13) THEN VORANIL = .;
   IF (SANOREX >= 13) THEN SANOREX = .;
   IF (MAZANOR >= 13) THEN MAZANOR = .;
   IF (RITALIN >= 13) THEN RITALIN = .;
   IF (CYLERT >= 13) THEN CYLERT = .;
   IF (DETAMP >= 13) THEN DETAMP = .;
   IF (METHI >= 13) THEN METHI = .;
   IF (METHAMP >= 13) THEN METHAMP = .;
   IF (OBLA >= 13) THEN OBLA = .;
   IF (STIMNEWA >= 991) THEN STIMNEWA = .;
   IF (STIMNEWB >= 991) THEN STIMNEWB = .;
   IF (STIMNEWC >= 991) THEN STIMNEWC = .;
   IF (STIMNEWD >= 991) THEN STIMNEWD = .;
   IF (STIMNOSP >= 13) THEN STIMNOSP = .;
   IF (STMDKNAM >= 13) THEN STMDKNAM = .;
   IF (STIMAGE >= 81) THEN STIMAGE = .;
   IF (STIMTOT >= 13) THEN STIMTOT = .;
   IF (STIMREC >= 13) THEN STIMREC = .;
   IF (STMYRFRQ >= 13) THEN STMYRFRQ = .;
   IF (STNEEDLE >= 13) THEN STNEEDLE = .;
   IF (STNDLREC >= 13) THEN STNDLREC = .;
   IF (AS5READ >= 13) THEN AS5READ = .;
   IF (ANALNONE >= 13) THEN ANALNONE = .;
   IF (DARVON >= 13) THEN DARVON = .;
   IF (DOLENE >= 13) THEN DOLENE = .;
   IF (SK65A >= 13) THEN SK65A = .;
   IF (WYGESIC >= 13) THEN WYGESIC = .;
   IF (LEVODRO >= 13) THEN LEVODRO = .;
   IF (PERCODAN >= 13) THEN PERCODAN = .;
   IF (DEMEROL >= 13) THEN DEMEROL = .;
   IF (DILAUD >= 13) THEN DILAUD = .;
   IF (TYLCOD >= 13) THEN TYLCOD = .;
   IF (PHENCOD >= 13) THEN PHENCOD = .;
   IF (TALWIN >= 13) THEN TALWIN = .;
   IF (TALWINNX >= 13) THEN TALWINNX = .;
   IF (TALACEN >= 13) THEN TALACEN = .;
   IF (PROPOXY >= 13) THEN PROPOXY = .;
   IF (CODEINE >= 13) THEN CODEINE = .;
   IF (ANILERID >= 13) THEN ANILERID = .;
   IF (MORPHINE >= 13) THEN MORPHINE = .;
   IF (METHDON >= 13) THEN METHDON = .;
   IF (STADOL >= 13) THEN STADOL = .;
   IF (ANALNEWA >= 991) THEN ANALNEWA = .;
   IF (ANALNEWB >= 991) THEN ANALNEWB = .;
   IF (ANALNEWC >= 991) THEN ANALNEWC = .;
   IF (ANLNOSP >= 13) THEN ANLNOSP = .;
   IF (ANLDKNAM >= 13) THEN ANLDKNAM = .;
   IF (ANALAGE >= 81) THEN ANALAGE = .;
   IF (ANALTOT >= 13) THEN ANALTOT = .;
   IF (ANALREC >= 13) THEN ANALREC = .;
   IF (ANLYRFRQ >= 13) THEN ANLYRFRQ = .;
   IF (MJOPP >= 81) THEN MJOPP = .;
   IF (MJAGE >= 81) THEN MJAGE = .;
   IF (MJTOT >= 13) THEN MJTOT = .;
   IF (MJREC >= 13) THEN MJREC = .;
   IF (MJDAY30A >= 81) THEN MJDAY30A = .;
   IF (MJAV30A >= 81) THEN MJAV30A = .;
   IF (MJAMT30A >= 81) THEN MJAMT30A = .;
   IF (MJYRFREQ >= 13) THEN MJYRFREQ = .;
   IF (MJJOINT >= 13) THEN MJJOINT = .;
   IF (MJPIPE >= 13) THEN MJPIPE = .;
   IF (MJBAKE >= 13) THEN MJBAKE = .;
   IF (MJCHEW >= 13) THEN MJCHEW = .;
   IF (MJNEWA >= 81) THEN MJNEWA = .;
   IF (MJNOSP >= 13) THEN MJNOSP = .;
   IF (AS7READ >= 13) THEN AS7READ = .;
   IF (GAS >= 13) THEN GAS = .;
   IF (SPPAINT >= 13) THEN SPPAINT = .;
   IF (AEROS >= 13) THEN AEROS = .;
   IF (GLUE >= 13) THEN GLUE = .;
   IF (SOLVENT >= 13) THEN SOLVENT = .;
   IF (AMYLNIT >= 13) THEN AMYLNIT = .;
   IF (ETHER >= 13) THEN ETHER = .;
   IF (NITOXID >= 13) THEN NITOXID = .;
   IF (CLEFLU >= 13) THEN CLEFLU = .;
   IF (INHNEWA >= 991) THEN INHNEWA = .;
   IF (INHNEWB >= 991) THEN INHNEWB = .;
   IF (INHNOSP >= 13) THEN INHNOSP = .;
   IF (INHDKNAM >= 13) THEN INHDKNAM = .;
   IF (INHAGE >= 81) THEN INHAGE = .;
   IF (INHTOT >= 13) THEN INHTOT = .;
   IF (INHREC >= 13) THEN INHREC = .;
   IF (INHYRFRQ >= 13) THEN INHYRFRQ = .;
   IF (GAS30A >= 13) THEN GAS30A = .;
   IF (SPPAN30A >= 13) THEN SPPAN30A = .;
   IF (AEROS30A >= 13) THEN AEROS30A = .;
   IF (GLUE30A >= 13) THEN GLUE30A = .;
   IF (SOLVN30A >= 13) THEN SOLVN30A = .;
   IF (AMLNT30A >= 13) THEN AMLNT30A = .;
   IF (ETHER30A >= 13) THEN ETHER30A = .;
   IF (NOX30A >= 13) THEN NOX30A = .;
   IF (CLFL30A >= 13) THEN CLFL30A = .;
   IF (INNEW30A >= 991) THEN INNEW30A = .;
   IF (INNEW30B >= 991) THEN INNEW30B = .;
   IF (IN30NOSP >= 13) THEN IN30NOSP = .;
   IF (INH30NO >= 13) THEN INH30NO = .;
   IF (INHDY30A >= 81) THEN INHDY30A = .;
   IF (INHEFF >= 13) THEN INHEFF = .;
   IF (INHPO >= 13) THEN INHPO = .;
   IF (INHQNC1 >= 13) THEN INHQNC1 = .;
   IF (INHQNC2 >= 13) THEN INHQNC2 = .;
   IF (INHQNC3 >= 13) THEN INHQNC3 = .;
   IF (INHQNC4 >= 13) THEN INHQNC4 = .;
   IF (INHQNC5 >= 13) THEN INHQNC5 = .;
   IF (INHQNC6 >= 13) THEN INHQNC6 = .;
   IF (INHQNC7 >= 13) THEN INHQNC7 = .;
   IF (INHQNC8 >= 13) THEN INHQNC8 = .;
   IF (INHQNC9 >= 13) THEN INHQNC9 = .;
   IF (INHQNC10 >= 13) THEN INHQNC10 = .;
   IF (INHANSY >= 13) THEN INHANSY = .;
   IF (COCOPP >= 81) THEN COCOPP = .;
   IF (COCAGE >= 81) THEN COCAGE = .;
   IF (COCTOT >= 13) THEN COCTOT = .;
   IF (COCREC >= 13) THEN COCREC = .;
   IF (COCUS30A >= 81) THEN COCUS30A = .;
   IF (COCYRFRQ >= 13) THEN COCYRFRQ = .;
   IF (COCSNIFF >= 13) THEN COCSNIFF = .;
   IF (COCSWAL >= 13) THEN COCSWAL = .;
   IF (COCIV >= 13) THEN COCIV = .;
   IF (FREEBASE >= 13) THEN FREEBASE = .;
   IF (COCNEWA >= 13) THEN COCNEWA = .;
   IF (COCNEWB >= 13) THEN COCNEWB = .;
   IF (COCNOSP >= 13) THEN COCNOSP = .;
   IF (CONDLREC >= 13) THEN CONDLREC = .;
   IF (CRAKREC >= 13) THEN CRAKREC = .;
   IF (CRKAM30A >= 981) THEN CRKAM30A = .;
   IF (CRAKBUCK >= 9981) THEN CRAKBUCK = .;
   IF (COCAM30A >= 13) THEN COCAM30A = .;
   IF (COCBUCK >= 9981) THEN COCBUCK = .;
   IF (AS9READ >= 13) THEN AS9READ = .;
   IF (LSD >= 13) THEN LSD = .;
   IF (PEYOTE >= 13) THEN PEYOTE = .;
   IF (MESC >= 13) THEN MESC = .;
   IF (PSILCY >= 13) THEN PSILCY = .;
   IF (PCP >= 13) THEN PCP = .;
   IF (ECSTASY >= 13) THEN ECSTASY = .;
   IF (HALNEWA >= 991) THEN HALNEWA = .;
   IF (HALNEWB >= 991) THEN HALNEWB = .;
   IF (HALNOSP >= 13) THEN HALNOSP = .;
   IF (HALDKNAM >= 13) THEN HALDKNAM = .;
   IF (HALLOPP >= 81) THEN HALLOPP = .;
   IF (HALLAGE >= 81) THEN HALLAGE = .;
   IF (HALLTOT >= 13) THEN HALLTOT = .;
   IF (HALLREC >= 13) THEN HALLREC = .;
   IF (HAL30USE >= 81) THEN HAL30USE = .;
   IF (HALYRFRQ >= 13) THEN HALYRFRQ = .;
   IF (PCPREC >= 13) THEN PCPREC = .;
   IF (AS10READ >= 13) THEN AS10READ = .;
   IF (HEROPP >= 81) THEN HEROPP = .;
   IF (HERAGE >= 81) THEN HERAGE = .;
   IF (HERTOT >= 13) THEN HERTOT = .;
   IF (HERREC >= 13) THEN HERREC = .;
   IF (HER30USE >= 81) THEN HER30USE = .;
   IF (HERNEEDL >= 13) THEN HERNEEDL = .;
   IF (HRNDLREC >= 13) THEN HRNDLREC = .;
   IF (AS11READ >= 13) THEN AS11READ = .;
   IF (CDCIG >= 13) THEN CDCIG = .;
   IF (CDALC >= 13) THEN CDALC = .;
   IF (CDSED >= 13) THEN CDSED = .;
   IF (CDTRAN >= 13) THEN CDTRAN = .;
   IF (CDSTM >= 13) THEN CDSTM = .;
   IF (CDANAL >= 13) THEN CDANAL = .;
   IF (CDMJ >= 13) THEN CDMJ = .;
   IF (CDINH >= 13) THEN CDINH = .;
   IF (CDCOC >= 13) THEN CDCOC = .;
   IF (CDHALL >= 13) THEN CDHALL = .;
   IF (CDHER >= 13) THEN CDHER = .;
   IF (CDOTHOP >= 13) THEN CDOTHOP = .;
   IF (CDNONE >= 13) THEN CDNONE = .;
   IF (EFFCIG >= 13) THEN EFFCIG = .;
   IF (EFFALC >= 13) THEN EFFALC = .;
   IF (EFFSED >= 13) THEN EFFSED = .;
   IF (EFFTRAN >= 13) THEN EFFTRAN = .;
   IF (EFFSTM >= 13) THEN EFFSTM = .;
   IF (EFFANAL >= 13) THEN EFFANAL = .;
   IF (EFFMJ >= 13) THEN EFFMJ = .;
   IF (EFFINH >= 13) THEN EFFINH = .;
   IF (EFFCOC >= 13) THEN EFFCOC = .;
   IF (EFFHALL >= 13) THEN EFFHALL = .;
   IF (EFFHER >= 13) THEN EFFHER = .;
   IF (EFFOTHOP >= 13) THEN EFFOTHOP = .;
   IF (EFFNONE >= 13) THEN EFFNONE = .;
   IF (UDAYCIG >= 13) THEN UDAYCIG = .;
   IF (UDAYALC >= 13) THEN UDAYALC = .;
   IF (UDAYSED >= 13) THEN UDAYSED = .;
   IF (UDAYTRAN >= 13) THEN UDAYTRAN = .;
   IF (UDAYSTM >= 13) THEN UDAYSTM = .;
   IF (UDAYANAL >= 13) THEN UDAYANAL = .;
   IF (UDAYMJ >= 13) THEN UDAYMJ = .;
   IF (UDAYINH >= 13) THEN UDAYINH = .;
   IF (UDAYCOC >= 13) THEN UDAYCOC = .;
   IF (UDAYHALL >= 13) THEN UDAYHALL = .;
   IF (UDAYHER >= 13) THEN UDAYHER = .;
   IF (UDAYOTH >= 13) THEN UDAYOTH = .;
   IF (UDAYNONE >= 13) THEN UDAYNONE = .;
   IF (DEPCIG >= 13) THEN DEPCIG = .;
   IF (DEPALC >= 13) THEN DEPALC = .;
   IF (DEPSED >= 13) THEN DEPSED = .;
   IF (DEPTRAN >= 13) THEN DEPTRAN = .;
   IF (DEPSTM >= 13) THEN DEPSTM = .;
   IF (DEPANAL >= 13) THEN DEPANAL = .;
   IF (DEPMJ >= 13) THEN DEPMJ = .;
   IF (DEPINH >= 13) THEN DEPINH = .;
   IF (DEPCOC >= 13) THEN DEPCOC = .;
   IF (DEPHALL >= 13) THEN DEPHALL = .;
   IF (DEPHER >= 13) THEN DEPHER = .;
   IF (DEPOTHOP >= 13) THEN DEPOTHOP = .;
   IF (DEPNONE >= 13) THEN DEPNONE = .;
   IF (WSCIG >= 13) THEN WSCIG = .;
   IF (WSALC >= 13) THEN WSALC = .;
   IF (WSSED >= 13) THEN WSSED = .;
   IF (WSTRAN >= 13) THEN WSTRAN = .;
   IF (WSSTM >= 13) THEN WSSTM = .;
   IF (WSANAL >= 13) THEN WSANAL = .;
   IF (WSMJ >= 13) THEN WSMJ = .;
   IF (WSINH >= 13) THEN WSINH = .;
   IF (WSCOC >= 13) THEN WSCOC = .;
   IF (WSHALL >= 13) THEN WSHALL = .;
   IF (WSHER >= 13) THEN WSHER = .;
   IF (WSOTHOP >= 13) THEN WSOTHOP = .;
   IF (WSNONE >= 13) THEN WSNONE = .;
   IF (ICELIFE >= 13) THEN ICELIFE = .;
   IF (ICEREC >= 13) THEN ICEREC = .;
   IF (AS12READ >= 13) THEN AS12READ = .;
   IF (GNNDLLIF >= 13) THEN GNNDLLIF = .;
   IF (GNNDLREC >= 13) THEN GNNDLREC = .;
   IF (GNNDLSED >= 13) THEN GNNDLSED = .;
   IF (GNNDLTRA >= 13) THEN GNNDLTRA = .;
   IF (GNNDLSTM >= 13) THEN GNNDLSTM = .;
   IF (GNNDLANL >= 13) THEN GNNDLANL = .;
   IF (GNNDLMJ >= 13) THEN GNNDLMJ = .;
   IF (GNNDLINH >= 13) THEN GNNDLINH = .;
   IF (GNNDLCOC >= 13) THEN GNNDLCOC = .;
   IF (GNNDLHAL >= 13) THEN GNNDLHAL = .;
   IF (GNNDLHER >= 13) THEN GNNDLHER = .;
   IF (GNNDLOPT >= 13) THEN GNNDLOPT = .;
   IF (GNNDLNON >= 13) THEN GNNDLNON = .;
   IF (GNNDLSHR >= 13) THEN GNNDLSHR = .;
   IF (AS13READ >= 13) THEN AS13READ = .;
   IF (NOBOOZYR >= 13) THEN NOBOOZYR = .;
   IF (ALCAGGR >= 13) THEN ALCAGGR = .;
   IF (ALCARGUM >= 13) THEN ALCARGUM = .;
   IF (ALCABSNT >= 13) THEN ALCABSNT = .;
   IF (ALCHIGH >= 13) THEN ALCHIGH = .;
   IF (ALCJOB >= 13) THEN ALCJOB = .;
   IF (ALCMATCD >= 13) THEN ALCMATCD = .;
   IF (ALCRELCD >= 13) THEN ALCRELCD = .;
   IF (ALCFRDCD >= 13) THEN ALCFRDCD = .;
   IF (ALCTOSS >= 13) THEN ALCTOSS = .;
   IF (ALCHOLIC >= 13) THEN ALCHOLIC = .;
   IF (ALCDRUNK >= 13) THEN ALCDRUNK = .;
   IF (ALCINTOX >= 13) THEN ALCINTOX = .;
   IF (ALCREM >= 13) THEN ALCREM = .;
   IF (ALCQUICK >= 13) THEN ALCQUICK = .;
   IF (ALCMORN >= 13) THEN ALCMORN = .;
   IF (ALCSHOOK >= 13) THEN ALCSHOOK = .;
   IF (ALCALONE >= 13) THEN ALCALONE = .;
   IF (ALCBRKPM >= 13) THEN ALCBRKPM = .;
   IF (AS13NONE >= 13) THEN AS13NONE = .;
   IF (DRDEPRSS >= 13) THEN DRDEPRSS = .;
   IF (DEPDRG1A >= 900) THEN DEPDRG1A = .;
   IF (DEPDRG2A >= 998) THEN DEPDRG2A = .;
   IF (DEPDRG3A >= 998) THEN DEPDRG3A = .;
   IF (DEPDRG4A >= 998) THEN DEPDRG4A = .;
   IF (DRARGUM >= 13) THEN DRARGUM = .;
   IF (ARGDRG1A >= 900) THEN ARGDRG1A = .;
   IF (ARGDRG2A >= 900) THEN ARGDRG2A = .;
   IF (ARGDRG3A >= 998) THEN ARGDRG3A = .;
   IF (DRALONE >= 13) THEN DRALONE = .;
   IF (ALNDRG1A >= 900) THEN ALNDRG1A = .;
   IF (ALNDRG2A >= 998) THEN ALNDRG2A = .;
   IF (ALNDRG3A >= 998) THEN ALNDRG3A = .;
   IF (DRANX >= 97) THEN DRANX = .;
   IF (ANXDRG1A >= 900) THEN ANXDRG1A = .;
   IF (ANXDRG2A >= 900) THEN ANXDRG2A = .;
   IF (ANXDRG3A >= 900) THEN ANXDRG3A = .;
   IF (DRHEALTH >= 13) THEN DRHEALTH = .;
   IF (HLTDRG1A >= 900) THEN HLTDRG1A = .;
   IF (HLTDRG2A >= 900) THEN HLTDRG2A = .;
   IF (HLTDRG3A >= 998) THEN HLTDRG3A = .;
   IF (DRNTHINK >= 97) THEN DRNTHINK = .;
   IF (NTKDRG1A >= 900) THEN NTKDRG1A = .;
   IF (NTKDRG2A >= 900) THEN NTKDRG2A = .;
   IF (NTKDRG3A >= 998) THEN NTKDRG3A = .;
   IF (NTKDRG4A >= 998) THEN NTKDRG4A = .;
   IF (DRUPSET >= 97) THEN DRUPSET = .;
   IF (UPSDRG1A >= 900) THEN UPSDRG1A = .;
   IF (UPSDRG2A >= 900) THEN UPSDRG2A = .;
   IF (UPSDRG3A >= 998) THEN UPSDRG3A = .;
   IF (DRLSWORK >= 96) THEN DRLSWORK = .;
   IF (LSWDRG1A >= 900) THEN LSWDRG1A = .;
   IF (LSWDRG2A >= 900) THEN LSWDRG2A = .;
   IF (LSWDRG3A >= 998) THEN LSWDRG3A = .;
   IF (DRSUSPIC >= 97) THEN DRSUSPIC = .;
   IF (SSPDRG1A >= 900) THEN SSPDRG1A = .;
   IF (SSPDRG2A >= 900) THEN SSPDRG2A = .;
   IF (SSPDRG3A >= 998) THEN SSPDRG3A = .;
   IF (DRCOPE >= 97) THEN DRCOPE = .;
   IF (CPEDRG1A >= 900) THEN CPEDRG1A = .;
   IF (CPEDRG2A >= 900) THEN CPEDRG2A = .;
   IF (CPEDRG3A >= 998) THEN CPEDRG3A = .;
   IF (DREMGMED >= 97) THEN DREMGMED = .;
   IF (EMDRG1A >= 900) THEN EMDRG1A = .;
   IF (EMDRG2A >= 900) THEN EMDRG2A = .;
   IF (EMDRG3A >= 998) THEN EMDRG3A = .;
   IF (EMDRG4A >= 998) THEN EMDRG4A = .;
   IF (RSKPKCIG >= 94) THEN RSKPKCIG = .;
   IF (RSKTRYMJ >= 94) THEN RSKTRYMJ = .;
   IF (RSKMJOCC >= 94) THEN RSKMJOCC = .;
   IF (RSKMJREG >= 94) THEN RSKMJREG = .;
   IF (RKTRYPCP >= 94) THEN RKTRYPCP = .;
   IF (RKPCPREG >= 94) THEN RKPCPREG = .;
   IF (RKTRYHER >= 92) THEN RKTRYHER = .;
   IF (RKHERREG >= 94) THEN RKHERREG = .;
   IF (RKTRYCOC >= 94) THEN RKTRYCOC = .;
   IF (RKCOCOCC >= 94) THEN RKCOCOCC = .;
   IF (RKCOCREG >= 94) THEN RKCOCREG = .;
   IF (RKCRKOCC >= 94) THEN RKCRKOCC = .;
   IF (RKANSOCC >= 94) THEN RKANSOCC = .;
   IF (RKANSREG >= 94) THEN RKANSREG = .;
   IF (RK2DRINK >= 94) THEN RK2DRINK = .;
   IF (RK5DRINK >= 94) THEN RK5DRINK = .;
   IF (RSKBINGE >= 94) THEN RSKBINGE = .;
   IF (HIGHBP >= 96) THEN HIGHBP = .;
   IF (BPMED >= 92) THEN BPMED = .;
   IF (WALKPAIN >= 94) THEN WALKPAIN = .;
   IF (TIMEPAIN >= 98) THEN TIMEPAIN = .;
   IF (UPSHOR >= 98) THEN UPSHOR = .;
   IF (ASTHMA >= 92) THEN ASTHMA = .;
   IF (TRPSYCH >= 92) THEN TRPSYCH = .;
   IF (HEART >= 94) THEN HEART = .;
   IF (FLU >= 94) THEN FLU = .;
   IF (ALLERG >= 94) THEN ALLERG = .;
   IF (HOSPYR >= 97) THEN HOSPYR = .;
   IF (SOREYR >= 94) THEN SOREYR = .;
   IF (RUNNYYR >= 94) THEN RUNNYYR = .;
   IF (COUGHYR >= 94) THEN COUGHYR = .;
   IF (PHLEGMYR >= 94) THEN PHLEGMYR = .;
   IF (HEALTHYR >= 94) THEN HEALTHYR = .;
   IF (HELTHINS >= 94) THEN HELTHINS = .;
   IF (BIRTHMON >= 94) THEN BIRTHMON = .;
   IF (MARITAL >= 85) THEN MARITAL = .;
   IF (NOMARR >= 85) THEN NOMARR = .;
   IF (WORKSTAT >= 96) THEN WORKSTAT = .;
   IF (PAYMO >= 85) THEN PAYMO = .;
   IF (PAYYR >= 91) THEN PAYYR = .;
   IF (ROCCUP2 >= 990) THEN ROCCUP2 = .;
   IF (BUSINES2 >= 990) THEN BUSINES2 = .;
   IF (SECTOR >= 94) THEN SECTOR = .;
   IF (NO5JOB >= 94) THEN NO5JOB = .;
   IF (WORKDAYS >= 94) THEN WORKDAYS = .;
   IF (WORKBLAH >= 85) THEN WORKBLAH = .;
   IF (CWE >= 92) THEN CWE = .;
   IF (FULLPART >= 94) THEN FULLPART = .;
   IF (CWEOCC2 >= 990) THEN CWEOCC2 = .;
   IF (CWEBUS2 >= 990) THEN CWEBUS2 = .;
   IF (CWESECTR >= 94) THEN CWESECTR = .;
   IF (EDUC >= 94) THEN EDUC = .;
   IF (GRADHS >= 92) THEN GRADHS = .;
   IF (DIPLOMA >= 94) THEN DIPLOMA = .;
   IF (ENROLLD >= 97) THEN ENROLLD = .;
   IF (STUDENT >= 97) THEN STUDENT = .;
   IF (SCHDAYS >= 92) THEN SCHDAYS = .;
   IF (SKIPPED >= 97) THEN SKIPPED = .;
   IF (SCHPLANS >= 94) THEN SCHPLANS = .;
   IF (MILES >= 99991) THEN MILES = .;
   IF (ACCID >= 85) THEN ACCID = .;
   IF (NOCHILD >= 94) THEN NOCHILD = .;
   IF (TOTPEOP >= 97) THEN TOTPEOP = .;
   IF (MOTHER >= 97) THEN MOTHER = .;
   IF (FATHER >= 97) THEN FATHER = .;
   IF (STEPMOM >= 97) THEN STEPMOM = .;
   IF (STEPDAD >= 97) THEN STEPDAD = .;
   IF (SPOUSE >= 97) THEN SPOUSE = .;
   IF (INLAW >= 93) THEN INLAW = .;
   IF (OWNCHILD >= 93) THEN OWNCHILD = .;
   IF (STEPCHLD >= 93) THEN STEPCHLD = .;
   IF (BROSIS >= 93) THEN BROSIS = .;
   IF (OTHREL >= 93) THEN OTHREL = .;
   IF (FRIENDS >= 93) THEN FRIENDS = .;
   IF (OTHERNON >= 93) THEN OTHERNON = .;
   IF (SERVICE >= 97) THEN SERVICE = .;
   IF (MILSTAT >= 94) THEN MILSTAT = .;
   IF (MOVDAWAY >= 94) THEN MOVDAWAY = .;
   IF (DORM >= 94) THEN DORM = .;
   IF (MILBASE >= 94) THEN MILBASE = .;
   IF (HOSP >= 94) THEN HOSP = .;
   IF (TELNO >= 13) THEN TELNO = .;
   IF (MOVES >= 94) THEN MOVES = .;
   IF (INCOME >= 85) THEN INCOME = .;
   IF (WKSWORKD >= 94) THEN WKSWORKD = .;
   IF (WKSFP >= 94) THEN WKSFP = .;
   IF (TOTFAMIN >= 85) THEN TOTFAMIN = .;
   IF (WAGES >= 94) THEN WAGES = .;
   IF (SELFEMPL >= 94) THEN SELFEMPL = .;
   IF (INTDIV >= 94) THEN INTDIV = .;
   IF (SOCSEC >= 94) THEN SOCSEC = .;
   IF (SSI >= 94) THEN SSI = .;
   IF (DISABLTY >= 94) THEN DISABLTY = .;
   IF (OTHRETIR >= 94) THEN OTHRETIR = .;
   IF (WELFARE >= 94) THEN WELFARE = .;
   IF (OTHSOURC >= 94) THEN OTHSOURC = .;
   IF (AMTWAGES >= 999992) THEN AMTWAGES = .;
   IF (AMTSELFE >= 999994) THEN AMTSELFE = .;
   IF (AMTINTDV >= 999994) THEN AMTINTDV = .;
   IF (AMTSOSEC >= 999994) THEN AMTSOSEC = .;
   IF (AMTSSI >= 999994) THEN AMTSSI = .;
   IF (AMTDISAB >= 999994) THEN AMTDISAB = .;
   IF (AMTOTRET >= 999994) THEN AMTOTRET = .;
   IF (AMTWLFAR >= 999994) THEN AMTWLFAR = .;
   IF (AMTOTSRC >= 999994) THEN AMTOTSRC = .;
   IF (UNDINT >= 94) THEN UNDINT = .;
   IF (COOPINT >= 98) THEN COOPINT = .;
   IF (PRIVACY >= 96) THEN PRIVACY = .;
   IF (PPRES >= 98) THEN PPRES = .;
   IF (SPRES >= 98) THEN SPRES = .;
   IF (PARPRES >= 98) THEN PARPRES = .;
   IF (OARPRES >= 98) THEN OARPRES = .;
   IF (OAPRES >= 98) THEN OAPRES = .;
   IF (CPRES >= 98) THEN CPRES = .;
   IF (OPRESSPA >= 98) THEN OPRESSPA = .;
   IF (OPRESSPB >= 98) THEN OPRESSPB = .;
   IF (OPRESNSP >= 95) THEN OPRESNSP = .;
   IF (DC >= 9) THEN DC = .;
   IF (IRHOGRP >= 13) THEN IRHOGRP = .;
   IF (IIHOGRP >= 9) THEN IIHOGRP = .;
   IF (IRMARIT >= 99) THEN IRMARIT = .;
   IF (IIMARIT >= 9) THEN IIMARIT = .;
   IF (IRWORKST >= 13) THEN IRWORKST = .;
   IF (IREARN >= 99) THEN IREARN = .;
   IF (IIEARN >= 9) THEN IIEARN = .;
   IF (IRINC47 >= 99) THEN IRINC47 = .;
   IF (IIINC47 >= 9) THEN IIINC47 = .;
   IF (IRINC48A >= 99) THEN IRINC48A = .;
   IF (IIINC48A >= 9) THEN IIINC48A = .;
   IF (IRINC49A >= 999999) THEN IRINC49A = .;
   IF (IIINC49A >= 9) THEN IIINC49A = .;
   IF (IRINC48B >= 99) THEN IRINC48B = .;
   IF (IIINC48B >= 9) THEN IIINC48B = .;
   IF (IRINC49B >= 999999) THEN IRINC49B = .;
   IF (IIINC49B >= 9) THEN IIINC49B = .;
   IF (IRINC48C >= 99) THEN IRINC48C = .;
   IF (IIINC48C >= 9) THEN IIINC48C = .;
   IF (IRINC49C >= 999999) THEN IRINC49C = .;
   IF (IIINC49C >= 9) THEN IIINC49C = .;
   IF (IRINC48D >= 99) THEN IRINC48D = .;
   IF (IIINC48D >= 9) THEN IIINC48D = .;
   IF (IRINC49D >= 999999) THEN IRINC49D = .;
   IF (IIINC49D >= 9) THEN IIINC49D = .;
   IF (IRINC48E >= 99) THEN IRINC48E = .;
   IF (IIINC48E >= 9) THEN IIINC48E = .;
   IF (IRINC49E >= 999999) THEN IRINC49E = .;
   IF (IIINC49E >= 9) THEN IIINC49E = .;
   IF (IRINC48F >= 99) THEN IRINC48F = .;
   IF (IIINC48F >= 9) THEN IIINC48F = .;
   IF (IRINC49F >= 999999) THEN IRINC49F = .;
   IF (IIINC49F >= 9) THEN IIINC49F = .;
   IF (IRINC48G >= 99) THEN IRINC48G = .;
   IF (IIINC48G >= 9) THEN IIINC48G = .;
   IF (IRINC49G >= 999999) THEN IRINC49G = .;
   IF (IIINC49G >= 9) THEN IIINC49G = .;
   IF (IRINC48H >= 99) THEN IRINC48H = .;
   IF (IIINC48H >= 9) THEN IIINC48H = .;
   IF (IRINC49H >= 999999) THEN IRINC49H = .;
   IF (IRINC48I >= 99) THEN IRINC48I = .;
   IF (IIINC48I >= 9) THEN IIINC48I = .;
   IF (IRINC49I >= 999999) THEN IRINC49I = .;
   IF (IIINC49I >= 9) THEN IIINC49I = .;
   IF (IRALCRC >= 9) THEN IRALCRC = .;
   IF (IRMJRC >= 9) THEN IRMJRC = .;
   IF (IRCOCRC >= 9) THEN IRCOCRC = .;
   IF (IRSEDRC >= 9) THEN IRSEDRC = .;
   IF (IRTRNRC >= 9) THEN IRTRNRC = .;
   IF (IRSTMRC >= 9) THEN IRSTMRC = .;
   IF (IRANLRC >= 9) THEN IRANLRC = .;
   IF (IRCIGRC >= 9) THEN IRCIGRC = .;
   IF (IROTBRC >= 9) THEN IROTBRC = .;
   IF (IRINHRC >= 9) THEN IRINHRC = .;
   IF (IRCRKRC >= 9) THEN IRCRKRC = .;
   IF (IRHALRC >= 9) THEN IRHALRC = .;
   IF (IRHERRC >= 9) THEN IRHERRC = .;
   IF (IRPCPRC >= 9) THEN IRPCPRC = .;
   IF (IRICERC >= 9) THEN IRICERC = .;
   IF (IRALCFQ >= 9) THEN IRALCFQ = .;
   IF (IRMJFQ >= 10) THEN IRMJFQ = .;
   IF (IRCOCFQ >= 9) THEN IRCOCFQ = .;
   IF (IRSEDFQ >= 9) THEN IRSEDFQ = .;
   IF (IRTRNFQ >= 9) THEN IRTRNFQ = .;
   IF (IRSTMFQ >= 9) THEN IRSTMFQ = .;
   IF (IRANLFQ >= 9) THEN IRANLFQ = .;
   IF (IROTBFQ >= 9) THEN IROTBFQ = .;
   IF (IRINHFQ >= 9) THEN IRINHFQ = .;
   IF (IRHALFQ >= 9) THEN IRHALFQ = .;
   IF (TOTINC >= 9999999) THEN TOTINC = .;
   IF (TOTCAT >= 99) THEN TOTCAT = .;
   IF (FAMINC >= 6) THEN FAMINC = .;
   IF (PEREARN >= 6) THEN PEREARN = .;
   IF (NEEDLREC >= 91) THEN NEEDLREC = .;
   IF (NDL90REC >= 91) THEN NDL90REC = .;
   IF (NDL90RC2 >= 81) THEN NDL90RC2 = .;
   IF (IRDEP >= 99) THEN IRDEP = .;
   IF (IRDEP1 >= 998) THEN IRDEP1 = .;
   IF (IRDEP2 >= 999) THEN IRDEP2 = .;
   IF (IRDEP3 >= 999) THEN IRDEP3 = .;
   IF (IRDEP4 >= 999) THEN IRDEP4 = .;
   IF (IRARG >= 99) THEN IRARG = .;
   IF (IRARG1 >= 998) THEN IRARG1 = .;
   IF (IRARG2 >= 999) THEN IRARG2 = .;
   IF (IRARG3 >= 999) THEN IRARG3 = .;
   IF (IRALN >= 99) THEN IRALN = .;
   IF (IRALN1 >= 998) THEN IRALN1 = .;
   IF (IRALN2 >= 999) THEN IRALN2 = .;
   IF (IRALN3 >= 999) THEN IRALN3 = .;
   IF (IRANX >= 99) THEN IRANX = .;
   IF (IRANX1 >= 998) THEN IRANX1 = .;
   IF (IRANX2 >= 999) THEN IRANX2 = .;
   IF (IRANX3 >= 999) THEN IRANX3 = .;
   IF (IRHLT >= 99) THEN IRHLT = .;
   IF (IRHLT1 >= 998) THEN IRHLT1 = .;
   IF (IRHLT2 >= 999) THEN IRHLT2 = .;
   IF (IRHLT3 >= 999) THEN IRHLT3 = .;
   IF (IRNTK >= 99) THEN IRNTK = .;
   IF (IRNTK1 >= 998) THEN IRNTK1 = .;
   IF (IRNTK2 >= 999) THEN IRNTK2 = .;
   IF (IRNTK3 >= 999) THEN IRNTK3 = .;
   IF (IRNTK4 >= 999) THEN IRNTK4 = .;
   IF (IRUPS >= 99) THEN IRUPS = .;
   IF (IRUPS1 >= 998) THEN IRUPS1 = .;
   IF (IRUPS2 >= 999) THEN IRUPS2 = .;
   IF (IRUPS3 >= 999) THEN IRUPS3 = .;
   IF (IRLSW >= 99) THEN IRLSW = .;
   IF (IRLSW1 >= 998) THEN IRLSW1 = .;
   IF (IRLSW2 >= 999) THEN IRLSW2 = .;
   IF (IRLSW3 >= 999) THEN IRLSW3 = .;
   IF (IRSSP >= 99) THEN IRSSP = .;
   IF (IRSSP1 >= 998) THEN IRSSP1 = .;
   IF (IRSSP2 >= 999) THEN IRSSP2 = .;
   IF (IRSSP3 >= 999) THEN IRSSP3 = .;
   IF (IRCPE >= 99) THEN IRCPE = .;
   IF (IRCPE1 >= 998) THEN IRCPE1 = .;
   IF (IRCPE2 >= 999) THEN IRCPE2 = .;
   IF (IRCPE3 >= 999) THEN IRCPE3 = .;
   IF (IREMG >= 99) THEN IREMG = .;
   IF (IREMG1 >= 998) THEN IREMG1 = .;
   IF (IREMG2 >= 999) THEN IREMG2 = .;
   IF (IREMG3 >= 999) THEN IREMG3 = .;
   IF (IREMG4 >= 999) THEN IREMG4 = .;
   IF (IRCDALC >= 13) THEN IRCDALC = .;
   IF (IRCDCIG >= 13) THEN IRCDCIG = .;
   IF (IRCDCOC >= 13) THEN IRCDCOC = .;
   IF (IRCDMJ >= 13) THEN IRCDMJ = .;
   IF (IREFALC >= 13) THEN IREFALC = .;
   IF (IREFCIG >= 13) THEN IREFCIG = .;
   IF (IREFCOC >= 13) THEN IREFCOC = .;
   IF (IREFMJ >= 13) THEN IREFMJ = .;
   IF (IRUDALC >= 13) THEN IRUDALC = .;
   IF (IRUDCIG >= 13) THEN IRUDCIG = .;
   IF (IRUDCOC >= 13) THEN IRUDCOC = .;
   IF (IRUDMJ >= 13) THEN IRUDMJ = .;
   IF (IRDPALC >= 13) THEN IRDPALC = .;
   IF (IRDPCIG >= 13) THEN IRDPCIG = .;
   IF (IRDPCOC >= 13) THEN IRDPCOC = .;
   IF (IRDPMJ >= 13) THEN IRDPMJ = .;
   IF (IRWSALC >= 13) THEN IRWSALC = .;
   IF (IRWSCIG >= 13) THEN IRWSCIG = .;
   IF (IRWSCOC >= 13) THEN IRWSCOC = .;
   IF (IRWSMJ >= 13) THEN IRWSMJ = .;
   IF (IRALCABS >= 13) THEN IRALCABS = .;
   IF (IRALCAGG >= 99) THEN IRALCAGG = .;
   IF (IRALCALO >= 99) THEN IRALCALO = .;
   IF (IRALCARG >= 99) THEN IRALCARG = .;
   IF (IRALCBRK >= 99) THEN IRALCBRK = .;
   IF (IRALCDRU >= 99) THEN IRALCDRU = .;
   IF (IRALCFRD >= 99) THEN IRALCFRD = .;
   IF (IRALCHIG >= 99) THEN IRALCHIG = .;
   IF (IRALCHOL >= 99) THEN IRALCHOL = .;
   IF (IRALCINT >= 99) THEN IRALCINT = .;
   IF (IRALCJOB >= 99) THEN IRALCJOB = .;
   IF (IRALCMAT >= 99) THEN IRALCMAT = .;
   IF (IRALCMOR >= 99) THEN IRALCMOR = .;
   IF (IRALCQUI >= 99) THEN IRALCQUI = .;
   IF (IRALCREL >= 99) THEN IRALCREL = .;
   IF (IRALCREM >= 99) THEN IRALCREM = .;
   IF (IRALCSHO >= 99) THEN IRALCSHO = .;
   IF (IRALCTOS >= 99) THEN IRALCTOS = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT CIGTRY cigtry. CIG5PK cig5pk. CIGAGE cigage.
         CIGYRS cigyrs. PACKS packs. CIGREC cigrec.
         AVCIG avcig. CIGTIME cigtime. SNUFREC snufrec.
         OTHTOB othtob. ALCTRY alctry. ALCREC alcrec.
         ALCAGE alcage. ALCDAYS alcdays. NODR30A nodr30a.
         DR5DAY dr5day. MODR30A modr30a. MODR30DY modr30dy.
         ALCPAT alcpat. DRUNKYR drunkyr. ALCSED alcsed.
         ALCTRAN alctran. ALCSTM alcstm. ALCANAL alcanal.
         ALCMJ alcmj. ALCINH alcinh. ALCCOC alccoc.
         ALCHAL alchal. ALCOPT alcopt. ALCNONE alcnone.
         ALCPREF alcpref. NOSEDAT nosedat. BUTISOL butisol.
         BUTICAPS buticaps. AMYTAL amytal. MEBARAL mebaral.
         PLACIDYL placidyl. DORIDEN doriden. NOLUDAR noludar.
         NEMBUTAL nembutal. SECONAL seconal. TUINAL tuinal.
         DALMANE dalmane. RESTORIL restoril. HALCION halcion.
         AMOBARB amobarb. PHENOBAR phenobar. METHAQ methaq.
         CHHYD chhyd. PENTOB pentob. SECOB secob.
         SEDNEWA sednewa. SEDNEWB sednewb. SEDNEWC sednewc.
         SEDNOSP sednosp. SEDDKNAM seddknam. SEDAGE sedage.
         SEDTOT sedtot. SEDREC sedrec. SEDYRFRQ sedyrfrq.
         AS3READ as3read. NOTRANQ notranq. VALIUM valium.
         LIBRIUM librium. LIMBTROL limbtrol. MENRIUM menrium.
         SERAX serax. TRANXENE tranxene. ATIVAN ativan.
         CENTRAX centrax. XANAX xanax. PAXIPAM paxipam.
         BUSPAR buspar. MILTOWN miltown. EQUANIL equanil.
         DEPROL deprol. VISTAR vistar. ATARAX atarax.
         DURRAX durrax. DIAZEPAM diazepam. SKLY skly.
         MEPROB meprob. TRNEWA trnewa. TRNEWB trnewb.
         TRNEWC trnewc. TRNOSP trnosp. TRDKNAM trdknam.
         TRANAGE tranage. TRANTOT trantot. TRANREC tranrec.
         TRNYRFRQ trnyrfrq. AS4READ as4read. NOSTIMS nostims.
         DEXED dexed. DEXAMYL dexamyl. ESKAT eskat.
         BENZ benz. BIPHET biphet. DESOXYN desoxyn.
         TENUATE tenuate. TEPANIL tepanil. DIDREX didrex.
         PLEGINE plegine. PRELUDIN preludin. IONAMIN ionamin.
         FASTIN fastin. PONDIMIN pondimin. VORANIL voranil.
         SANOREX sanorex. MAZANOR mazanor. RITALIN ritalin.
         CYLERT cylert. DETAMP detamp. METHI methi.
         METHAMP methamp. OBLA obla. STIMNEWA stimnewa.
         STIMNEWB stimnewb. STIMNEWC stimnewc. STIMNEWD stimnewd.
         STIMNOSP stimnosp. STMDKNAM stmdknam. STIMAGE stimage.
         STIMTOT stimtot. STIMREC stimrec. STMYRFRQ stmyrfrq.
         STNEEDLE stneedle. STNDLREC stndlrec. AS5READ as5read.
         ANALNONE analnone. DARVON darvon. DOLENE dolene.
         SK65A sk65a. WYGESIC wygesic. LEVODRO levodro.
         PERCODAN percodan. DEMEROL demerol. DILAUD dilaud.
         TYLCOD tylcod. PHENCOD phencod. TALWIN talwin.
         TALWINNX talwinnx. TALACEN talacen. PROPOXY propoxy.
         CODEINE codeine. ANILERID anilerid. MORPHINE morphine.
         METHDON methdon. STADOL stadol. ANALNEWA analnewa.
         ANALNEWB analnewb. ANALNEWC analnewc. ANLNOSP anlnosp.
         ANLDKNAM anldknam. ANALAGE analage. ANALTOT analtot.
         ANALREC analrec. ANLYRFRQ anlyrfrq. MJOPP mjopp.
         MJAGE mjage. MJTOT mjtot. MJREC mjrec.
         MJDAY30A mjday30a. MJAV30A mjav30a. MJAMT30A mjamt30a.
         MJYRFREQ mjyrfreq. MJJOINT mjjoint. MJPIPE mjpipe.
         MJBAKE mjbake. MJCHEW mjchew. MJNEWA mjnewa.
         MJNOSP mjnosp. AS7READ as7read. GAS gas.
         SPPAINT sppaint. AEROS aeros. GLUE glue.
         SOLVENT solvent. AMYLNIT amylnit. ETHER ether.
         NITOXID nitoxid. CLEFLU cleflu. INHNEWA inhnewa.
         INHNEWB inhnewb. INHNOSP inhnosp. INHDKNAM inhdknam.
         INHAGE inhage. INHTOT inhtot. INHREC inhrec.
         INHYRFRQ inhyrfrq. GAS30A gas30a. SPPAN30A sppan30a.
         AEROS30A aeros30a. GLUE30A glue30a. SOLVN30A solvn30a.
         AMLNT30A amlnt30a. ETHER30A ether30a. NOX30A nox30a.
         CLFL30A clfl30a. INNEW30A innew30a. INNEW30B innew30b.
         IN30NOSP in30nosp. INH30NO inh30no. INHDY30A inhdy30a.
         INHEFF inheff. INHPO inhpo. INHQNC1 inhqnc1f.
         INHQNC2 inhqnc2f. INHQNC3 inhqnc3f. INHQNC4 inhqnc4f.
         INHQNC5 inhqnc5f. INHQNC6 inhqnc6f. INHQNC7 inhqnc7f.
         INHQNC8 inhqnc8f. INHQNC9 inhqnc9f. INHQNC10 inhqnc0f.
         INHANSY inhansy. COCOPP cocopp. COCAGE cocage.
         COCTOT coctot. COCREC cocrec. COCUS30A cocus30a.
         COCYRFRQ cocyrfrq. COCSNIFF cocsniff. COCSWAL cocswal.
         COCIV cociv. FREEBASE freebase. COCNEWA cocnewa.
         COCNEWB cocnewb. COCNOSP cocnosp. CONDLREC condlrec.
         CRAKREC crakrec. CRKAM30A crkam30a. CRAKBUCK crakbuck.
         COCAM30A cocam30a. COCBUCK cocbuck. AS9READ as9read.
         LSD lsd. PEYOTE peyote. MESC mesc.
         PSILCY psilcy. PCP pcp. ECSTASY ecstasy.
         HALNEWA halnewa. HALNEWB halnewb. HALNOSP halnosp.
         HALDKNAM haldknam. HALLOPP hallopp. HALLAGE hallage.
         HALLTOT halltot. HALLREC hallrec. HAL30USE hal30use.
         HALYRFRQ halyrfrq. PCPREC pcprec. AS10READ as10read.
         HEROPP heropp. HERAGE herage. HERTOT hertot.
         HERREC herrec. HER30USE her30use. HERNEEDL herneedl.
         HRNDLREC hrndlrec. AS11READ as11read. CDCIG cdcig.
         CDALC cdalc. CDSED cdsed. CDTRAN cdtran.
         CDSTM cdstm. CDANAL cdanal. CDMJ cdmj.
         CDINH cdinh. CDCOC cdcoc. CDHALL cdhall.
         CDHER cdher. CDOTHOP cdothop. CDNONE cdnone.
         EFFCIG effcig. EFFALC effalc. EFFSED effsed.
         EFFTRAN efftran. EFFSTM effstm. EFFANAL effanal.
         EFFMJ effmj. EFFINH effinh. EFFCOC effcoc.
         EFFHALL effhall. EFFHER effher. EFFOTHOP effothop.
         EFFNONE effnone. UDAYCIG udaycig. UDAYALC udayalc.
         UDAYSED udaysed. UDAYTRAN udaytran. UDAYSTM udaystm.
         UDAYANAL udayanal. UDAYMJ udaymj. UDAYINH udayinh.
         UDAYCOC udaycoc. UDAYHALL udayhall. UDAYHER udayher.
         UDAYOTH udayoth. UDAYNONE udaynone. DEPCIG depcig.
         DEPALC depalc. DEPSED depsed. DEPTRAN deptran.
         DEPSTM depstm. DEPANAL depanal. DEPMJ depmj.
         DEPINH depinh. DEPCOC depcoc. DEPHALL dephall.
         DEPHER depher. DEPOTHOP depothop. DEPNONE depnone.
         WSCIG wscig. WSALC wsalc. WSSED wssed.
         WSTRAN wstran. WSSTM wsstm. WSANAL wsanal.
         WSMJ wsmj. WSINH wsinh. WSCOC wscoc.
         WSHALL wshall. WSHER wsher. WSOTHOP wsothop.
         WSNONE wsnone. ICELIFE icelife. ICEREC icerec.
         AS12READ as12read. GNNDLLIF gnndllif. GNNDLREC gnndlrec.
         GNNDLSED gnndlsed. GNNDLTRA gnndltra. GNNDLSTM gnndlstm.
         GNNDLANL gnndlanl. GNNDLMJ gnndlmj. GNNDLINH gnndlinh.
         GNNDLCOC gnndlcoc. GNNDLHAL gnndlhal. GNNDLHER gnndlher.
         GNNDLOPT gnndlopt. GNNDLNON gnndlnon. GNNDLSHR gnndlshr.
         AS13READ as13read. NOBOOZYR noboozyr. ALCAGGR alcaggr.
         ALCARGUM alcargum. ALCABSNT alcabsnt. ALCHIGH alchigh.
         ALCJOB alcjob. ALCMATCD alcmatcd. ALCRELCD alcrelcd.
         ALCFRDCD alcfrdcd. ALCTOSS alctoss. ALCHOLIC alcholic.
         ALCDRUNK alcdrunk. ALCINTOX alcintox. ALCREM alcrem.
         ALCQUICK alcquick. ALCMORN alcmorn. ALCSHOOK alcshook.
         ALCALONE alcalone. ALCBRKPM alcbrkpm. AS13NONE as13none.
         DRDEPRSS drdeprss. DEPDRG1A depdrg1a. DEPDRG2A depdrg2a.
         DEPDRG3A depdrg3a. DEPDRG4A depdrg4a. DRARGUM drargum.
         ARGDRG1A argdrg1a. ARGDRG2A argdrg2a. ARGDRG3A argdrg3a.
         DRALONE dralone. ALNDRG1A alndrg1a. ALNDRG2A alndrg2a.
         ALNDRG3A alndrg3a. DRANX dranx. ANXDRG1A anxdrg1a.
         ANXDRG2A anxdrg2a. ANXDRG3A anxdrg3a. DRHEALTH drhealth.
         HLTDRG1A hltdrg1a. HLTDRG2A hltdrg2a. HLTDRG3A hltdrg3a.
         DRNTHINK drnthink. NTKDRG1A ntkdrg1a. NTKDRG2A ntkdrg2a.
         NTKDRG3A ntkdrg3a. NTKDRG4A ntkdrg4a. DRUPSET drupset.
         UPSDRG1A upsdrg1a. UPSDRG2A upsdrg2a. UPSDRG3A upsdrg3a.
         DRLSWORK drlswork. LSWDRG1A lswdrg1a. LSWDRG2A lswdrg2a.
         LSWDRG3A lswdrg3a. DRSUSPIC drsuspic. SSPDRG1A sspdrg1a.
         SSPDRG2A sspdrg2a. SSPDRG3A sspdrg3a. DRCOPE drcope.
         CPEDRG1A cpedrg1a. CPEDRG2A cpedrg2a. CPEDRG3A cpedrg3a.
         DREMGMED dremgmed. EMDRG1A emdrg1a. EMDRG2A emdrg2a.
         EMDRG3A emdrg3a. EMDRG4A emdrg4a. RSKPKCIG rskpkcig.
         RSKTRYMJ rsktrymj. RSKMJOCC rskmjocc. RSKMJREG rskmjreg.
         RKTRYPCP rktrypcp. RKPCPREG rkpcpreg. RKTRYHER rktryher.
         RKHERREG rkherreg. RKTRYCOC rktrycoc. RKCOCOCC rkcococc.
         RKCOCREG rkcocreg. RKCRKOCC rkcrkocc. RKANSOCC rkansocc.
         RKANSREG rkansreg. RK2DRINK rk2drink. RK5DRINK rk5drink.
         RSKBINGE rskbinge. HIGHBP highbp. BPMED bpmed.
         WALKPAIN walkpain. TIMEPAIN timepain. UPSHOR upshor.
         ASTHMA asthma. TRPSYCH trpsych. HEART heart.
         FLU flu. ALLERG allerg. HOSPYR hospyr.
         SOREYR soreyr. RUNNYYR runnyyr. COUGHYR coughyr.
         PHLEGMYR phlegmyr. HEALTHYR healthyr. HELTHINS helthins.
         MARITAL marital. NOMARR nomarr. WORKSTAT workstat.
         PAYMO paymo. PAYYR payyr. ROCCUP2 roccup2f.
         BUSINES2 businesf. SECTOR sector. NO5JOB no5job.
         WORKDAYS workdays. WORKBLAH workblah. CWE cwe.
         FULLPART fullpart. CWEOCC2 cweocc2f. CWEBUS2 cwebus2f.
         CWESECTR cwesectr. EDUC educ. GRADHS gradhs.
         DIPLOMA diploma. ENROLLD enrolld. STUDENT student.
         SCHDAYS schdays. SKIPPED skipped. SCHPLANS schplans.
         MILES miles. ACCID accid. NOCHILD nochild.
         TOTPEOP totpeop. MOTHER mother. FATHER father.
         STEPMOM stepmom. STEPDAD stepdad. SPOUSE spouse.
         INLAW inlaw. OWNCHILD ownchild. STEPCHLD stepchld.
         BROSIS brosis. OTHREL othrel. FRIENDS friends.
         OTHERNON othernon. SERVICE service. MILSTAT milstat.
         MOVDAWAY movdaway. DORM dorm. MILBASE milbase.
         HOSP hosp. TELNO telno. MOVES moves.
         INCOME income. WKSWORKD wksworkd. WKSFP wksfp.
         TOTFAMIN totfamin. WAGES wages. SELFEMPL selfempl.
         INTDIV intdiv. SOCSEC socsec. SSI ssi.
         DISABLTY disablty. OTHRETIR othretir. WELFARE welfare.
         OTHSOURC othsourc. AMTWAGES amtwages. AMTSELFE amtselfe.
         AMTINTDV amtintdv. AMTSOSEC amtsosec. AMTSSI amtssi.
         AMTDISAB amtdisab. AMTOTRET amtotret. AMTWLFAR amtwlfar.
         AMTOTSRC amtotsrc. BAP bap. EAP eap.
         LANGVER langver. UNDINT undint. COOPINT coopint.
         PRIVACY privacy. PPRES ppres. SPRES spres.
         PARPRES parpres. OARPRES oarpres. OAPRES oapres.
         CPRES cpres. OPRESSPA opresspa. OPRESSPB opresspb.
         OPRESNSP opresnsp. POPDEN popden. POPDEN2 popden2f.
         DC dc. CENCTY cencty. URBARE urbare.
         REGION region. DIVISION division. HSPHCONC hsphconc.
         HSPPCONC hsppconc. NHBHCONC nhbhconc. NHBPCONC nhbpconc.
         OWNOCONC ownoconc. IIAGE iiage. IRSEX irsex.
         IISEX iisex. IRRACE irrace. IIRACE iirace.
         IRHOIND irhoind. IIHOIND iihoind. IRHOGRP irhogrp.
         IIHOGRP iihogrp. IRMARIT irmarit. IIMARIT iimarit.
         IREDUC ireduc. IIEDUC iieduc. IRHSGRAD irhsgrad.
         IIHSGRAD iihsgrad. IRWORKST irworkst. IIWORKST iiworkst.
         IRINSUR irinsur. IIINSUR iiinsur. IREARN irearn.
         IIEARN iiearn. IRINC47 irinc47f. IIINC47 iiinc47f.
         IRINC48A irinc48a. IIINC48A iiinc48a. IRINC49A irinc49a.
         IIINC49A iiinc49a. IRINC48B irinc48b. IIINC48B iiinc48b.
         IRINC49B irinc49b. IIINC49B iiinc49b. IRINC48C irinc48c.
         IIINC48C iiinc48c. IRINC49C irinc49c. IIINC49C iiinc49c.
         IRINC48D irinc48d. IIINC48D iiinc48d. IRINC49D irinc49d.
         IIINC49D iiinc49d. IRINC48E irinc48e. IIINC48E iiinc48e.
         IRINC49E irinc49e. IIINC49E iiinc49e. IRINC48F irinc48f.
         IIINC48F iiinc48f. IRINC49F irinc49f. IIINC49F iiinc49f.
         IRINC48G irinc48g. IIINC48G iiinc48g. IRINC49G irinc49g.
         IIINC49G iiinc49g. IRINC48H irinc48h. IIINC48H iiinc48h.
         IRINC49H irinc49h. IIINC49H iiinc49h. IRINC48I irinc48i.
         IIINC48I iiinc48i. IRINC49I irinc49i. IIINC49I iiinc49i.
         IRALCRC iralcrc. IIALCRC iialcrc. IRMJRC irmjrc.
         IIMJRC iimjrc. IRCOCRC ircocrc. IICOCRC iicocrc.
         IRSEDRC irsedrc. IISEDRC iisedrc. IRTRNRC irtrnrc.
         IITRNRC iitrnrc. IRSTMRC irstmrc. IISTMRC iistmrc.
         IRANLRC iranlrc. IIANLRC iianlrc. IRCIGRC ircigrc.
         IICIGRC iicigrc. IROTBRC irotbrc. IIOTBRC iiotbrc.
         IRINHRC irinhrc. IIINHRC iiinhrc. IRCRKRC ircrkrc.
         IICRKRC iicrkrc. IRHALRC irhalrc. IIHALRC iihalrc.
         IRHERRC irherrc. IIHERRC iiherrc. IRPCPRC irpcprc.
         IIPCPRC iipcprc. IRICERC iricerc. IIICERC iiicerc.
         IRALCFQ iralcfq. IIALCFQ iialcfq. IRMJFQ irmjfq.
         IIMJFQ iimjfq. IRCOCFQ ircocfq. IICOCFQ iicocfq.
         IRSEDFQ irsedfq. IISEDFQ iisedfq. IRTRNFQ irtrnfq.
         IITRNFQ iitrnfq. IRSTMFQ irstmfq. IISTMFQ iistmfq.
         IRANLFQ iranlfq. IIANLFQ iianlfq. IROTBFQ irotbfq.
         IIOTBFQ iiotbfq. IRINHFQ irinhfq. IIINHFQ iiinhfq.
         IRHALFQ irhalfq. IIHALFQ iihalfq. CATAGE catage.
         CATAG2 catag2ff. RACE race. EDUCCAT2 educcatf.
         EMPSTAT2 empstatf. TOTINC totinc. TOTCAT totcat.
         FAMINC faminc. PEREARN perearn. HALFLAG halflag.
         HALYR halyr. HALMON halmon. PCPFLAG pcpflag.
         PCPYR pcpyr. PCPMON pcpmon. STMFLAG stmflag.
         STMYR stmyr. STMMON stmmon. SEDFLAG sedflag.
         SEDYR sedyr. SEDMON sedmon. TRQFLAG trqflag.
         TRQYR trqyr. TRQMON trqmon. ANLFLAG anlflag.
         ANLYR anlyr. ANLMON anlmon. ALCFLAG alcflag.
         ALCYR alcyr. ALCMON alcmon. CIGFLAG cigflag.
         CIGYR cigyr. CIGMON cigmon. SMKFLAG smkflag.
         SMKYR smkyr. SMKMON smkmon. HERFLAG herflag.
         HERYR heryr. HERMON hermon. MRJFLAG mrjflag.
         MRJYR mrjyr. MRJMON mrjmon. COCFLAG cocflag.
         COCYR cocyr. COCMON cocmon. CRKFLAG crkflag.
         CRKYR crkyr. CRKMON crkmon. INHFLAG inhflag.
         INHYR inhyr. INHMON inhmon. NEEDLREC needlrec.
         NDL90REC ndl90rec. NDL90RC2 ndl90rcf. NEDFLAG2 nedflagf.
         NEDYR2 nedyr2ff. HALYRF halyrf. HALMONF halmonf.
         HALWKF halwkf. STMYRF stmyrf. STMMONF stmmonf.
         STMWKF stmwkf. SEDYRF sedyrf. SEDMONF sedmonf.
         SEDWKF sedwkf. TRQYRF trqyrf. TRQMONF trqmonf.
         TRQWKF trqwkf. ANLYRF anlyrf. ANLMONF anlmonf.
         ANLWKF anlwkf. ALCYRF alcyrf. ALCMONF alcmonf.
         ALCWKF alcwkf. SMKYRF smkyrf. SMKMONF smkmonf.
         SMKWKF smkwkf. MRJYRF mrjyrf. MRJMONF mrjmonf.
         MRJWKF mrjwkf. COCYRF cocyrf. COCMONF cocmonf.
         COCWKF cocwkf. INHYRF inhyrf. INHMONF inhmonf.
         INHWKF inhwkf. PSYFLAG2 psyflagf. PSYYR2 psyyr2ff.
         PSYMON2 psymon2f. SUMFLAG sumflag. SUMYR sumyr.
         SUMMON summon. MJOFLAG mjoflag. MJOYR2 mjoyr2ff.
         MJOMON2 mjomon2f. AEROS2 aeros2ff. ALCDAYS2 alcdaysf.
         ALCDAYS3 alcday0f. ALCMON2 alcmon2f. AMYLNIT2 amylnitf.
         AVCIG2 avcig2ff. AVCIG3 avcig3ff. CIGMON2 cigmon2f.
         CLEFLU2 cleflu2f. COCIV2 cociv2ff. COCNEWA2 cocnewaf.
         COCSNIF2 cocsni0f. COCSWAL2 cocswalf. COCTOT2 coctot2f.
         COCTOT3 coctot3f. DCOTSMSA dcotsmsa. DRINKER2 drinkerf.
         DRUNKYR2 drunkyrf. ETHER2 ether2ff. FREEBAS2 freebasf.
         GAS2 gas2ffff. GLUE2 glue2fff. GNDLSHR2 gndlshrf.
         HVYDRK2 hvydrk2f. LSD2 lsd2ffff. MESC2 mesc2fff.
         MJDY30A2 mjdy30af. MJDY30A3 mjdy300f. MJTOT2 mjtot2ff.
         MJTOT3 mjtot3ff. MRJMON2 mrjmon2f. NEDFLAG3 nedfla0f.
         NITOXID2 nitoxidf. NOTMARJ notmarj. PEYOTE2 peyote2f.
         PSILCY2 psilcy2f. RACESEX racesex. SOLVENT2 solventf.
         SPPAINT2 sppaintf. IRAS13 iras13ff. IRDEP irdep.
         IRDEP1 irdep1ff. IRDEP2 irdep2ff. IRDEP3 irdep3ff.
         IRDEP4 irdep4ff. IRARG irarg. IRARG1 irarg1ff.
         IRARG2 irarg2ff. IRARG3 irarg3ff. IRALN iraln.
         IRALN1 iraln1ff. IRALN2 iraln2ff. IRALN3 iraln3ff.
         IRANX iranx. IRANX1 iranx1ff. IRANX2 iranx2ff.
         IRANX3 iranx3ff. IRHLT irhlt. IRHLT1 irhlt1ff.
         IRHLT2 irhlt2ff. IRHLT3 irhlt3ff. IRNTK irntk.
         IRNTK1 irntk1ff. IRNTK2 irntk2ff. IRNTK3 irntk3ff.
         IRNTK4 irntk4ff. IRUPS irups. IRUPS1 irups1ff.
         IRUPS2 irups2ff. IRUPS3 irups3ff. IRLSW irlsw.
         IRLSW1 irlsw1ff. IRLSW2 irlsw2ff. IRLSW3 irlsw3ff.
         IRSSP irssp. IRSSP1 irssp1ff. IRSSP2 irssp2ff.
         IRSSP3 irssp3ff. IRCPE ircpe. IRCPE1 ircpe1ff.
         IRCPE2 ircpe2ff. IRCPE3 ircpe3ff. IREMG iremg.
         IREMG1 iremg1ff. IREMG2 iremg2ff. IREMG3 iremg3ff.
         IREMG4 iremg4ff. ANYPROB anyprob. TWOPROB twoprob.
         THREPROB threprob. ALNALC2 alnalc2f. ALNCIG2 alncig2f.
         ALNCOC2 alncoc2f. ALNMRJ2 alnmrj2f. ANXALC2 anxalc2f.
         ANXCIG2 anxcig2f. ANXCOC2 anxcoc2f. ANXMRJ2 anxmrj2f.
         ARGALC2 argalc2f. ARGCIG2 argcig2f. ARGCOC2 argcoc2f.
         ARGMRJ2 argmrj2f. CPEALC2 cpealc2f. CPECIG2 cpecig2f.
         CPECOC2 cpecoc2f. CPEMRJ2 cpemrj2f. DEPALC2 depalc2f.
         DEPCIG2 depcig2f. DEPCOC2 depcoc2f. DEPMRJ2 depmrj2f.
         EMALC2 emalc2ff. EMCIG2 emcig2ff. EMCOC2 emcoc2ff.
         EMMRJ2 emmrj2ff. HLTALC2 hltalc2f. HLTCIG2 hltcig2f.
         HLTCOC2 hltcoc2f. HLTMRJ2 hltmrj2f. LSWALC2 lswalc2f.
         LSWCIG2 lswcig2f. LSWCOC2 lswcoc2f. LSWMRJ2 lswmrj2f.
         NTKALC2 ntkalc2f. NTKCIG2 ntkcig2f. NTKCOC2 ntkcoc2f.
         NTKMRJ2 ntkmrj2f. SSPALC2 sspalc2f. SSPCIG2 sspcig2f.
         SSPCOC2 sspcoc2f. SSPMRJ2 sspmrj2f. UPSALC2 upsalc2f.
         UPSCIG2 upscig2f. UPSCOC2 upscoc2f. UPSMRJ2 upsmrj2f.
         PRB1ALC prb1alc. PRB1CIG prb1cig. PRB1COC prb1coc.
         PRB1MRJ prb1mrj. PRB2ALC prb2alc. PRB2CIG prb2cig.
         PRB2COC prb2coc. PRB2MRJ prb2mrj. PRB3ALC prb3alc.
         PRB3CIG prb3cig. PRB3COC prb3coc. PRB3MRJ prb3mrj.
         IRCDALC ircdalc. IRCDCIG ircdcig. IRCDCOC ircdcoc.
         IRCDMJ ircdmj. IREFALC irefalc. IREFCIG irefcig.
         IREFCOC irefcoc. IREFMJ irefmj. IRUDALC irudalc.
         IRUDCIG irudcig. IRUDCOC irudcoc. IRUDMJ irudmj.
         IRDPALC irdpalc. IRDPCIG irdpcig. IRDPCOC irdpcoc.
         IRDPMJ irdpmj. IRWSALC irwsalc. IRWSCIG irwscig.
         IRWSCOC irwscoc. IRWSMJ irwsmj. ALCPROBS alcprobs.
         CIGPROBS cigprobs. COCPROBS cocprobs. MJPROBS mjprobs.
         IRNOBOOZ irnobooz. IRALCABS iralcabs. IRALCAGG iralcagg.
         IRALCALO iralcalo. IRALCARG iralcarg. IRALCBRK iralcbrk.
         IRALCDRU iralcdru. IRALCFRD iralcfrd. IRALCHIG iralchig.
         IRALCHOL iralchol. IRALCINT iralcint. IRALCJOB iralcjob.
         IRALCMAT iralcmat. IRALCMOR iralcmor. IRALCQUI iralcqui.
         IRALCREL iralcrel. IRALCREM iralcrem. IRALCSHO iralcsho.
         IRALCTOS iralctos. ANYALC anyalc. THREALC threalc.
         ALCONLYL alconlyl. ALCONLYY alconlyy. ALCONLYM alconlym.
         ILLONLYL illonlyl. ILLONLYY illonlyy. ILLONLYM illonlym.
         MRJONLYL mrjonlyl. MRJONLYY mrjonlyy. MRJONLYM mrjonlym.
         PSYONLYL psyonlyl. PSYONLYY psyonlyy. PSYONLYM psyonlym.
         OTHONLYL othonlyl. OTHONLYY othonlyy. OTHONLYM othonlym.
         ALCILLL alcilll. ALCILLY alcilly. ALCILLM alcillm.
         ALCMRJL alcmrjl. ALCMRJY alcmrjy. ALCMRJM alcmrjm.
         ALCPSYL alcpsyl. ALCPSYY alcpsyy. ALCPSYM alcpsym.
         ALCOTHL alcothl. ALCOTHY alcothy. ALCOTHM alcothm.
         SUB1LIF sub1lif. SUB1YR sub1yr. SUB1MON sub1mon.
         SUB2LIF sub2lif. SUB2YR sub2yr. SUB2MON sub2mon.
         SUB3LIF sub3lif. SUB3YR sub3yr. SUB3MON sub3mon.
          ;

RUN ;
